# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/public/fix_suggestion.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/public/fix_suggestion.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from zetasql.wasi._pb2.zetasql.public import error_location_pb2 as zetasql_dot_public_dot_error__location__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#zetasql/public/fix_suggestion.proto\x12\x07zetasql\x1a#zetasql/public/error_location.proto\"A\n\x08\x46ixRange\x12%\n\x05start\x18\x01 \x01(\x0b\x32\x16.zetasql.ErrorLocation\x12\x0e\n\x06length\x18\x02 \x01(\x05\">\n\x08TextEdit\x12 \n\x05range\x18\x01 \x01(\x0b\x32\x11.zetasql.FixRange\x12\x10\n\x08new_text\x18\x02 \x01(\t\".\n\x05\x45\x64its\x12%\n\ntext_edits\x18\x01 \x03(\x0b\x32\x11.zetasql.TextEdit\"3\n\x03\x46ix\x12\r\n\x05title\x18\x01 \x01(\t\x12\x1d\n\x05\x65\x64its\x18\x02 \x01(\x0b\x32\x0e.zetasql.Edits\"<\n\x13\x45rrorFixSuggestions\x12%\n\x0f\x66ix_suggestions\x18\x01 \x03(\x0b\x32\x0c.zetasql.FixB\x14\n\x12\x63om.google.zetasql')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.public.fix_suggestion_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasql'
  _globals['_FIXRANGE']._serialized_start=85
  _globals['_FIXRANGE']._serialized_end=150
  _globals['_TEXTEDIT']._serialized_start=152
  _globals['_TEXTEDIT']._serialized_end=214
  _globals['_EDITS']._serialized_start=216
  _globals['_EDITS']._serialized_end=262
  _globals['_FIX']._serialized_start=264
  _globals['_FIX']._serialized_end=315
  _globals['_ERRORFIXSUGGESTIONS']._serialized_start=317
  _globals['_ERRORFIXSUGGESTIONS']._serialized_end=377
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/public/type_parameters.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/public/type_parameters.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from zetasql.wasi._pb2.zetasql.public import simple_value_pb2 as zetasql_dot_public_dot_simple__value__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$zetasql/public/type_parameters.proto\x12\x07zetasql\x1a!zetasql/public/simple_value.proto\"\xfe\x02\n\x13TypeParametersProto\x12\x44\n\x16string_type_parameters\x18\x01 \x01(\x0b\x32\".zetasql.StringTypeParametersProtoH\x00\x12\x46\n\x17numeric_type_parameters\x18\x02 \x01(\x0b\x32#.zetasql.NumericTypeParametersProtoH\x00\x12H\n\x18\x65xtended_type_parameters\x18\x03 \x01(\x0b\x32$.zetasql.ExtendedTypeParametersProtoH\x00\x12J\n\x19timestamp_type_parameters\x18\x04 \x01(\x0b\x32%.zetasql.TimestampTypeParametersProtoH\x00\x12\x30\n\nchild_list\x18\x64 \x03(\x0b\x32\x1c.zetasql.TypeParametersProtoB\x11\n\x0ftype_parameters\"S\n\x19StringTypeParametersProto\x12\x14\n\nmax_length\x18\x01 \x01(\x03H\x00\x12\x17\n\ris_max_length\x18\x02 \x01(\x08H\x00\x42\x07\n\x05param\"1\n\x1cTimestampTypeParametersProto\x12\x11\n\tprecision\x18\x01 \x01(\x03\"w\n\x1aNumericTypeParametersProto\x12\x13\n\tprecision\x18\x01 \x01(\x03H\x00\x12\x1a\n\x10is_max_precision\x18\x02 \x01(\x08H\x00\x12\r\n\x05scale\x18\x03 \x01(\x03*\x06\x08\xe8\x07\x10\xd1\x0f\x42\x11\n\x0fprecision_param\"L\n\x1b\x45xtendedTypeParametersProto\x12-\n\nparameters\x18\x01 \x03(\x0b\x32\x19.zetasql.SimpleValueProtoB+\n\x12\x63om.google.zetasqlB\x15ZetaSQLTypeParameters')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.public.type_parameters_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasqlB\025ZetaSQLTypeParameters'
  _globals['_TYPEPARAMETERSPROTO']._serialized_start=85
  _globals['_TYPEPARAMETERSPROTO']._serialized_end=467
  _globals['_STRINGTYPEPARAMETERSPROTO']._serialized_start=469
  _globals['_STRINGTYPEPARAMETERSPROTO']._serialized_end=552
  _globals['_TIMESTAMPTYPEPARAMETERSPROTO']._serialized_start=554
  _globals['_TIMESTAMPTYPEPARAMETERSPROTO']._serialized_end=603
  _globals['_NUMERICTYPEPARAMETERSPROTO']._serialized_start=605
  _globals['_NUMERICTYPEPARAMETERSPROTO']._serialized_end=724
  _globals['_EXTENDEDTYPEPARAMETERSPROTO']._serialized_start=726
  _globals['_EXTENDEDTYPEPARAMETERSPROTO']._serialized_end=802
# @@protoc_insertion_point(module_scope)



from zetasql.wasi._pb2.zetasql.public import error_location_pb2 as _error_location_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DeprecationWarning(_message.Message):
    __slots__ = ("kind",)
    class Kind(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        __Kind__switch_must_have_a_default__: _ClassVar[DeprecationWarning.Kind]
        UNKNOWN: _ClassVar[DeprecationWarning.Kind]
        DEPRECATED_FUNCTION: _ClassVar[DeprecationWarning.Kind]
        DEPRECATED_FUNCTION_SIGNATURE: _ClassVar[DeprecationWarning.Kind]
        PROTO3_FIELD_PRESENCE: _ClassVar[DeprecationWarning.Kind]
        QUERY_TOO_COMPLEX: _ClassVar[DeprecationWarning.Kind]
        DEPRECATED_ANONYMIZATION_OPTION_KAPPA: _ClassVar[DeprecationWarning.Kind]
        PIVOT_OR_UNPIVOT_ON_ARRAY_SCAN: _ClassVar[DeprecationWarning.Kind]
        TABLE_SYNTAX_ARGUMENT_RESOLUTION_ORDER: _ClassVar[DeprecationWarning.Kind]
        PIPE_WINDOW: _ClassVar[DeprecationWarning.Kind]
        RESERVED_KEYWORD: _ClassVar[DeprecationWarning.Kind]
        LEGACY_FUNCTION_OPTIONS_PLACEMENT: _ClassVar[DeprecationWarning.Kind]
        LATERAL_COLUMN_REFERENCE: _ClassVar[DeprecationWarning.Kind]
    __Kind__switch_must_have_a_default__: DeprecationWarning.Kind
    UNKNOWN: DeprecationWarning.Kind
    DEPRECATED_FUNCTION: DeprecationWarning.Kind
    DEPRECATED_FUNCTION_SIGNATURE: DeprecationWarning.Kind
    PROTO3_FIELD_PRESENCE: DeprecationWarning.Kind
    QUERY_TOO_COMPLEX: DeprecationWarning.Kind
    DEPRECATED_ANONYMIZATION_OPTION_KAPPA: DeprecationWarning.Kind
    PIVOT_OR_UNPIVOT_ON_ARRAY_SCAN: DeprecationWarning.Kind
    TABLE_SYNTAX_ARGUMENT_RESOLUTION_ORDER: DeprecationWarning.Kind
    PIPE_WINDOW: DeprecationWarning.Kind
    RESERVED_KEYWORD: DeprecationWarning.Kind
    LEGACY_FUNCTION_OPTIONS_PLACEMENT: DeprecationWarning.Kind
    LATERAL_COLUMN_REFERENCE: DeprecationWarning.Kind
    KIND_FIELD_NUMBER: _ClassVar[int]
    kind: DeprecationWarning.Kind
    def __init__(self, kind: _Optional[_Union[DeprecationWarning.Kind, str]] = ...) -> None: ...

class FreestandingDeprecationWarning(_message.Message):
    __slots__ = ("message", "caret_string", "error_location", "deprecation_warning")
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    CARET_STRING_FIELD_NUMBER: _ClassVar[int]
    ERROR_LOCATION_FIELD_NUMBER: _ClassVar[int]
    DEPRECATION_WARNING_FIELD_NUMBER: _ClassVar[int]
    message: str
    caret_string: str
    error_location: _error_location_pb2.ErrorLocation
    deprecation_warning: DeprecationWarning
    def __init__(self, message: _Optional[str] = ..., caret_string: _Optional[str] = ..., error_location: _Optional[_Union[_error_location_pb2.ErrorLocation, _Mapping]] = ..., deprecation_warning: _Optional[_Union[DeprecationWarning, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/public/proto/logging.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/public/proto/logging.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"zetasql/public/proto/logging.proto\x12\x07zetasql\x1a\x1egoogle/protobuf/duration.proto\"\xfb\x01\n\x0e\x45xecutionStats\x12,\n\twall_time\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x08\x63pu_time\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1d\n\x15stack_available_bytes\x18\x04 \x01(\x04\x12\x1d\n\x15stack_peak_used_bytes\x18\x05 \x01(\x04\"P\n\rParserVariant\x12\x16\n\x12PARSER_UNSPECIFIED\x10\x00\x12\x10\n\x0cPARSER_BISON\x10\x01\x12\x15\n\x11PARSER_TEXTMAPPER\x10\x02\"\xd4\x03\n\x10\x41nalyzerLogEntry\x12\x1a\n\x12num_lexical_tokens\x18\x01 \x01(\x03\x12\x38\n\x17overall_execution_stats\x18\x02 \x01(\x0b\x32\x17.zetasql.ExecutionStats\x12P\n\x15\x65xecution_stats_by_op\x18\x03 \x03(\x0b\x32\x31.zetasql.AnalyzerLogEntry.ExecutionStatsByOpEntry\x1a\x81\x01\n\x17\x45xecutionStatsByOpEntry\x12>\n\x03key\x18\x01 \x01(\x0e\x32\x31.zetasql.AnalyzerLogEntry.LoggedOperationCategory\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.zetasql.ExecutionStats\"\x93\x01\n\x17LoggedOperationCategory\x12%\n!UNKNOWN_LOGGED_OPERATION_CATEGORY\x10\x00\x12\n\n\x06PARSER\x10\x01\x12\x0c\n\x08RESOLVER\x10\x02\x12\x0c\n\x08REWRITER\x10\x03\x12\x14\n\x10\x43\x41TALOG_RESOLVER\x10\x04\x12\r\n\tVALIDATOR\x10\x05\"\x04\x08\x06\x10\x06\x42\x02P\x01')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.public.proto.logging_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'P\001'
  _globals['_EXECUTIONSTATS']._serialized_start=80
  _globals['_EXECUTIONSTATS']._serialized_end=331
  _globals['_EXECUTIONSTATS_PARSERVARIANT']._serialized_start=251
  _globals['_EXECUTIONSTATS_PARSERVARIANT']._serialized_end=331
  _globals['_ANALYZERLOGENTRY']._serialized_start=334
  _globals['_ANALYZERLOGENTRY']._serialized_end=802
  _globals['_ANALYZERLOGENTRY_EXECUTIONSTATSBYOPENTRY']._serialized_start=523
  _globals['_ANALYZERLOGENTRY_EXECUTIONSTATSBYOPENTRY']._serialized_end=652
  _globals['_ANALYZERLOGENTRY_LOGGEDOPERATIONCATEGORY']._serialized_start=655
  _globals['_ANALYZERLOGENTRY_LOGGEDOPERATIONCATEGORY']._serialized_end=802
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/public/annotation.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/public/annotation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from zetasql.wasi._pb2.zetasql.public import simple_value_pb2 as zetasql_dot_public_dot_simple__value__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fzetasql/public/annotation.proto\x12\x07zetasql\x1a!zetasql/public/simple_value.proto\"G\n\x0f\x41nnotationProto\x12\n\n\x02id\x18\x01 \x01(\x03\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x19.zetasql.SimpleValueProto\"\xc0\x01\n\x12\x41nnotationMapProto\x12\x0f\n\x07is_null\x18\x04 \x01(\x08\x12-\n\x0b\x61nnotations\x18\x01 \x03(\x0b\x32\x18.zetasql.AnnotationProto\x12\x36\n\rarray_element\x18\x02 \x01(\x0b\x32\x1b.zetasql.AnnotationMapProtoB\x02\x18\x01\x12\x32\n\rstruct_fields\x18\x03 \x03(\x0b\x32\x1b.zetasql.AnnotationMapProtoB*\n\x12\x63om.google.zetasqlB\x11ZetaSQLAnnotation\xf8\x01\x01')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.public.annotation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasqlB\021ZetaSQLAnnotation\370\001\001'
  _globals['_ANNOTATIONMAPPROTO'].fields_by_name['array_element']._loaded_options = None
  _globals['_ANNOTATIONMAPPROTO'].fields_by_name['array_element']._serialized_options = b'\030\001'
  _globals['_ANNOTATIONPROTO']._serialized_start=79
  _globals['_ANNOTATIONPROTO']._serialized_end=150
  _globals['_ANNOTATIONMAPPROTO']._serialized_start=153
  _globals['_ANNOTATIONMAPPROTO']._serialized_end=345
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/common/match_recognize/match_test_result.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/common/match_recognize/match_test_result.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6zetasql/common/match_recognize/match_test_result.proto\x12!zetasql.functions.match_recognize\"4\n\x10MatchResultProto\x12\r\n\x05match\x18\x01 \x03(\t\x12\x11\n\trep_count\x18\x03 \x01(\x05\"\xa8\x01\n\x19MatchPartitionResultProto\x12\x44\n\x07\x61\x64\x64_row\x18\x01 \x03(\x0b\x32\x33.zetasql.functions.match_recognize.MatchResultProto\x12\x45\n\x08\x66inalize\x18\x02 \x01(\x0b\x32\x33.zetasql.functions.match_recognize.MatchResultProto')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.common.match_recognize.match_test_result_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_MATCHRESULTPROTO']._serialized_start=93
  _globals['_MATCHRESULTPROTO']._serialized_end=145
  _globals['_MATCHPARTITIONRESULTPROTO']._serialized_start=148
  _globals['_MATCHPARTITIONRESULTPROTO']._serialized_end=316
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/public/proto/wire_format_annotation.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/public/proto/wire_format_annotation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1zetasql/public/proto/wire_format_annotation.proto\x12\x07zetasql\x1a google/protobuf/descriptor.proto\"\"\n WireFormatAnnotationEmptyMessage*C\n\tTableType\x12\x16\n\x12\x44\x45\x46\x41ULT_TABLE_TYPE\x10\x00\x12\r\n\tSQL_TABLE\x10\x01\x12\x0f\n\x0bVALUE_TABLE\x10\x02:;\n\x11struct_field_name\x12\x1d.google.protobuf.FieldOptions\x18\xd5\xe6\x9b! \x01(\t:6\n\x0cis_raw_proto\x12\x1d.google.protobuf.FieldOptions\x18\x8a\x90\x8bN \x01(\x08:;\n\x10is_hidden_column\x12\x1d.google.protobuf.FieldOptions\x18\xe7\xc1\x93\xa1\x01 \x01(\x08:5\n\nis_measure\x12\x1d.google.protobuf.FieldOptions\x18\xc8\xdd\xbe\xff\x01 \x01(\x08:6\n\nis_wrapper\x12\x1f.google.protobuf.MessageOptions\x18\xe2\xa3\xdb\x17 \x01(\x08:5\n\tis_struct\x12\x1f.google.protobuf.MessageOptions\x18\xc2\x92\xdb\x17 \x01(\x08:J\n\ntable_type\x12\x1f.google.protobuf.MessageOptions\x18\x84\xdf\xb3) \x01(\x0e\x32\x12.zetasql.TableTypeB/\n\x12\x63om.google.zetasqlB\x19WireFormatAnnotationProto')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.public.proto.wire_format_annotation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasqlB\031WireFormatAnnotationProto'
  _globals['_TABLETYPE']._serialized_start=132
  _globals['_TABLETYPE']._serialized_end=199
  _globals['_WIREFORMATANNOTATIONEMPTYMESSAGE']._serialized_start=96
  _globals['_WIREFORMATANNOTATIONEMPTYMESSAGE']._serialized_end=130
# @@protoc_insertion_point(module_scope)



from zetasql.wasi._pb2.zetasql.public import type_pb2 as _type_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class UnsupportedFieldsEnum(_message.Message):
    __slots__ = ()
    class UnsupportedFields(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNSUPPORTED_FIELDS_INVALID: _ClassVar[UnsupportedFieldsEnum.UnsupportedFields]
        FAIL: _ClassVar[UnsupportedFieldsEnum.UnsupportedFields]
        IGNORE: _ClassVar[UnsupportedFieldsEnum.UnsupportedFields]
        PLACEHOLDER: _ClassVar[UnsupportedFieldsEnum.UnsupportedFields]
    UNSUPPORTED_FIELDS_INVALID: UnsupportedFieldsEnum.UnsupportedFields
    FAIL: UnsupportedFieldsEnum.UnsupportedFields
    IGNORE: UnsupportedFieldsEnum.UnsupportedFields
    PLACEHOLDER: UnsupportedFieldsEnum.UnsupportedFields
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/public/functions/match_recognize/compiled_pattern.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/public/functions/match_recognize/compiled_pattern.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from zetasql.wasi._pb2.zetasql.resolved_ast import resolved_ast_enums_pb2 as zetasql_dot_resolved__ast_dot_resolved__ast__enums__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?zetasql/public/functions/match_recognize/compiled_pattern.proto\x12!zetasql.functions.match_recognize\x1a-zetasql/resolved_ast/resolved_ast_enums.proto\"\xfa\x04\n\x11StateMachineProto\x12R\n\x03nfa\x18\x01 \x01(\x0b\x32\x45.zetasql.functions.match_recognize.StateMachineProto.CompiledNFAProto\x12Z\n\x15\x61\x66ter_match_skip_mode\x18\x02 \x01(\x0e\x32;.zetasql.ResolvedMatchRecognizeScanEnums.AfterMatchSkipMode\x12\x1a\n\x12longest_match_mode\x18\x03 \x01(\x08\x1a\x98\x03\n\x10\x43ompiledNFAProto\x12`\n\x06states\x18\x01 \x03(\x0b\x32P.zetasql.functions.match_recognize.StateMachineProto.CompiledNFAProto.StateProto\x12\x13\n\x0bstart_state\x18\x02 \x01(\x05\x12\x13\n\x0b\x66inal_state\x18\x03 \x01(\x05\x12\x1d\n\x15num_pattern_variables\x18\x04 \x01(\x05\x1ak\n\tEdgeProto\x12\x10\n\x08to_state\x18\x03 \x01(\x05\x12\x18\n\x10pattern_variable\x18\x04 \x01(\x05\x12\x18\n\x10is_head_anchored\x18\x05 \x01(\x08\x12\x18\n\x10is_tail_anchored\x18\x06 \x01(\x08\x1al\n\nStateProto\x12^\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32O.zetasql.functions.match_recognize.StateMachineProto.CompiledNFAProto.EdgeProto\"p\n\x14\x43ompiledPatternProto\x12M\n\rstate_machine\x18\x01 \x01(\x0b\x32\x34.zetasql.functions.match_recognize.StateMachineProtoH\x00\x42\t\n\x07variant')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.public.functions.match_recognize.compiled_pattern_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_STATEMACHINEPROTO']._serialized_start=150
  _globals['_STATEMACHINEPROTO']._serialized_end=784
  _globals['_STATEMACHINEPROTO_COMPILEDNFAPROTO']._serialized_start=376
  _globals['_STATEMACHINEPROTO_COMPILEDNFAPROTO']._serialized_end=784
  _globals['_STATEMACHINEPROTO_COMPILEDNFAPROTO_EDGEPROTO']._serialized_start=567
  _globals['_STATEMACHINEPROTO_COMPILEDNFAPROTO_EDGEPROTO']._serialized_end=674
  _globals['_STATEMACHINEPROTO_COMPILEDNFAPROTO_STATEPROTO']._serialized_start=676
  _globals['_STATEMACHINEPROTO_COMPILEDNFAPROTO_STATEPROTO']._serialized_end=784
  _globals['_COMPILEDPATTERNPROTO']._serialized_start=786
  _globals['_COMPILEDPATTERNPROTO']._serialized_end=898
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/public/simple_value.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/public/simple_value.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!zetasql/public/simple_value.proto\x12\x07zetasql\"\xca\x01\n\x10SimpleValueProto\x12\x15\n\x0bint64_value\x18\x01 \x01(\x03H\x00\x12\x16\n\x0cstring_value\x18\x02 \x01(\tH\x00\x12\x14\n\nbool_value\x18\x03 \x01(\x08H\x00\x12\x16\n\x0c\x64ouble_value\x18\x04 \x01(\x01H\x00\x12\x15\n\x0b\x62ytes_value\x18\x05 \x01(\x0cH\x00\x12\x39\n.__SimpleValueProto__switch_must_have_a_default\x18\xff\x01 \x01(\x08H\x00\x42\x07\n\x05valueB(\n\x12\x63om.google.zetasqlB\x12ZetaSQLSimpleValue')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.public.simple_value_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasqlB\022ZetaSQLSimpleValue'
  _globals['_SIMPLEVALUEPROTO']._serialized_start=47
  _globals['_SIMPLEVALUEPROTO']._serialized_end=249
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class SignatureArgumentKind(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    ARG_TYPE_FIXED: _ClassVar[SignatureArgumentKind]
    ARG_TYPE_ANY_1: _ClassVar[SignatureArgumentKind]
    ARG_TYPE_ANY_2: _ClassVar[SignatureArgumentKind]
    ARG_TYPE_ANY_3: _ClassVar[SignatureArgumentKind]
    ARG_TYPE_ANY_4: _ClassVar[SignatureArgumentKind]
    ARG_TYPE_ANY_5: _ClassVar[SignatureArgumentKind]
    ARG_ARRAY_TYPE_ANY_1: _ClassVar[SignatureArgumentKind]
    ARG_ARRAY_TYPE_ANY_2: _ClassVar[SignatureArgumentKind]
    ARG_ARRAY_TYPE_ANY_3: _ClassVar[SignatureArgumentKind]
    ARG_ARRAY_TYPE_ANY_4: _ClassVar[SignatureArgumentKind]
    ARG_ARRAY_TYPE_ANY_5: _ClassVar[SignatureArgumentKind]
    ARG_PROTO_MAP_ANY: _ClassVar[SignatureArgumentKind]
    ARG_PROTO_MAP_KEY_ANY: _ClassVar[SignatureArgumentKind]
    ARG_PROTO_MAP_VALUE_ANY: _ClassVar[SignatureArgumentKind]
    ARG_PROTO_ANY: _ClassVar[SignatureArgumentKind]
    ARG_STRUCT_ANY: _ClassVar[SignatureArgumentKind]
    ARG_ENUM_ANY: _ClassVar[SignatureArgumentKind]
    ARG_TYPE_ARBITRARY: _ClassVar[SignatureArgumentKind]
    ARG_TYPE_RELATION: _ClassVar[SignatureArgumentKind]
    ARG_TYPE_VOID: _ClassVar[SignatureArgumentKind]
    ARG_TYPE_MODEL: _ClassVar[SignatureArgumentKind]
    ARG_TYPE_CONNECTION: _ClassVar[SignatureArgumentKind]
    ARG_TYPE_DESCRIPTOR: _ClassVar[SignatureArgumentKind]
    ARG_TYPE_LAMBDA: _ClassVar[SignatureArgumentKind]
    ARG_RANGE_TYPE_ANY_1: _ClassVar[SignatureArgumentKind]
    ARG_TYPE_GRAPH_NODE: _ClassVar[SignatureArgumentKind]
    ARG_TYPE_GRAPH_EDGE: _ClassVar[SignatureArgumentKind]
    ARG_TYPE_GRAPH_ELEMENT: _ClassVar[SignatureArgumentKind]
    ARG_TYPE_GRAPH_PATH: _ClassVar[SignatureArgumentKind]
    ARG_TYPE_GRAPH: _ClassVar[SignatureArgumentKind]
    ARG_TYPE_SEQUENCE: _ClassVar[SignatureArgumentKind]
    ARG_MEASURE_TYPE_ANY_1: _ClassVar[SignatureArgumentKind]
    ARG_MAP_TYPE_ANY_1_2: _ClassVar[SignatureArgumentKind]
    __SignatureArgumentKind__switch_must_have_a_default__: _ClassVar[SignatureArgumentKind]
ARG_TYPE_FIXED: SignatureArgumentKind
ARG_TYPE_ANY_1: SignatureArgumentKind
ARG_TYPE_ANY_2: SignatureArgumentKind
ARG_TYPE_ANY_3: SignatureArgumentKind
ARG_TYPE_ANY_4: SignatureArgumentKind
ARG_TYPE_ANY_5: SignatureArgumentKind
ARG_ARRAY_TYPE_ANY_1: SignatureArgumentKind
ARG_ARRAY_TYPE_ANY_2: SignatureArgumentKind
ARG_ARRAY_TYPE_ANY_3: SignatureArgumentKind
ARG_ARRAY_TYPE_ANY_4: SignatureArgumentKind
ARG_ARRAY_TYPE_ANY_5: SignatureArgumentKind
ARG_PROTO_MAP_ANY: SignatureArgumentKind
ARG_PROTO_MAP_KEY_ANY: SignatureArgumentKind
ARG_PROTO_MAP_VALUE_ANY: SignatureArgumentKind
ARG_PROTO_ANY: SignatureArgumentKind
ARG_STRUCT_ANY: SignatureArgumentKind
ARG_ENUM_ANY: SignatureArgumentKind
ARG_TYPE_ARBITRARY: SignatureArgumentKind
ARG_TYPE_RELATION: SignatureArgumentKind
ARG_TYPE_VOID: SignatureArgumentKind
ARG_TYPE_MODEL: SignatureArgumentKind
ARG_TYPE_CONNECTION: SignatureArgumentKind
ARG_TYPE_DESCRIPTOR: SignatureArgumentKind
ARG_TYPE_LAMBDA: SignatureArgumentKind
ARG_RANGE_TYPE_ANY_1: SignatureArgumentKind
ARG_TYPE_GRAPH_NODE: SignatureArgumentKind
ARG_TYPE_GRAPH_EDGE: SignatureArgumentKind
ARG_TYPE_GRAPH_ELEMENT: SignatureArgumentKind
ARG_TYPE_GRAPH_PATH: SignatureArgumentKind
ARG_TYPE_GRAPH: SignatureArgumentKind
ARG_TYPE_SEQUENCE: SignatureArgumentKind
ARG_MEASURE_TYPE_ANY_1: SignatureArgumentKind
ARG_MAP_TYPE_ANY_1_2: SignatureArgumentKind
__SignatureArgumentKind__switch_must_have_a_default__: SignatureArgumentKind

class FunctionEnums(_message.Message):
    __slots__ = ()
    class ArgumentCardinality(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        REQUIRED: _ClassVar[FunctionEnums.ArgumentCardinality]
        REPEATED: _ClassVar[FunctionEnums.ArgumentCardinality]
        OPTIONAL: _ClassVar[FunctionEnums.ArgumentCardinality]
    REQUIRED: FunctionEnums.ArgumentCardinality
    REPEATED: FunctionEnums.ArgumentCardinality
    OPTIONAL: FunctionEnums.ArgumentCardinality
    class ProcedureArgumentMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        NOT_SET: _ClassVar[FunctionEnums.ProcedureArgumentMode]
        IN: _ClassVar[FunctionEnums.ProcedureArgumentMode]
        OUT: _ClassVar[FunctionEnums.ProcedureArgumentMode]
        INOUT: _ClassVar[FunctionEnums.ProcedureArgumentMode]
    NOT_SET: FunctionEnums.ProcedureArgumentMode
    IN: FunctionEnums.ProcedureArgumentMode
    OUT: FunctionEnums.ProcedureArgumentMode
    INOUT: FunctionEnums.ProcedureArgumentMode
    class WindowOrderSupport(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        ORDER_UNSUPPORTED: _ClassVar[FunctionEnums.WindowOrderSupport]
        ORDER_OPTIONAL: _ClassVar[FunctionEnums.WindowOrderSupport]
        ORDER_REQUIRED: _ClassVar[FunctionEnums.WindowOrderSupport]
    ORDER_UNSUPPORTED: FunctionEnums.WindowOrderSupport
    ORDER_OPTIONAL: FunctionEnums.WindowOrderSupport
    ORDER_REQUIRED: FunctionEnums.WindowOrderSupport
    class Mode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        SCALAR: _ClassVar[FunctionEnums.Mode]
        AGGREGATE: _ClassVar[FunctionEnums.Mode]
        ANALYTIC: _ClassVar[FunctionEnums.Mode]
    SCALAR: FunctionEnums.Mode
    AGGREGATE: FunctionEnums.Mode
    ANALYTIC: FunctionEnums.Mode
    class Volatility(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        IMMUTABLE: _ClassVar[FunctionEnums.Volatility]
        STABLE: _ClassVar[FunctionEnums.Volatility]
        VOLATILE: _ClassVar[FunctionEnums.Volatility]
    IMMUTABLE: FunctionEnums.Volatility
    STABLE: FunctionEnums.Volatility
    VOLATILE: FunctionEnums.Volatility
    class TableValuedFunctionType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        INVALID: _ClassVar[FunctionEnums.TableValuedFunctionType]
        FIXED_OUTPUT_SCHEMA_TVF: _ClassVar[FunctionEnums.TableValuedFunctionType]
        FORWARD_INPUT_SCHEMA_TO_OUTPUT_SCHEMA_TVF: _ClassVar[FunctionEnums.TableValuedFunctionType]
        TEMPLATED_SQL_TVF: _ClassVar[FunctionEnums.TableValuedFunctionType]
        FORWARD_INPUT_SCHEMA_TO_OUTPUT_SCHEMA_WITH_APPENDED_COLUMNS: _ClassVar[FunctionEnums.TableValuedFunctionType]
        BASIS_TVF: _ClassVar[FunctionEnums.TableValuedFunctionType]
    INVALID: FunctionEnums.TableValuedFunctionType
    FIXED_OUTPUT_SCHEMA_TVF: FunctionEnums.TableValuedFunctionType
    FORWARD_INPUT_SCHEMA_TO_OUTPUT_SCHEMA_TVF: FunctionEnums.TableValuedFunctionType
    TEMPLATED_SQL_TVF: FunctionEnums.TableValuedFunctionType
    FORWARD_INPUT_SCHEMA_TO_OUTPUT_SCHEMA_WITH_APPENDED_COLUMNS: FunctionEnums.TableValuedFunctionType
    BASIS_TVF: FunctionEnums.TableValuedFunctionType
    class ArgumentCollationMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        AFFECTS_NONE: _ClassVar[FunctionEnums.ArgumentCollationMode]
        AFFECTS_OPERATION: _ClassVar[FunctionEnums.ArgumentCollationMode]
        AFFECTS_PROPAGATION: _ClassVar[FunctionEnums.ArgumentCollationMode]
        AFFECTS_OPERATION_AND_PROPAGATION: _ClassVar[FunctionEnums.ArgumentCollationMode]
    AFFECTS_NONE: FunctionEnums.ArgumentCollationMode
    AFFECTS_OPERATION: FunctionEnums.ArgumentCollationMode
    AFFECTS_PROPAGATION: FunctionEnums.ArgumentCollationMode
    AFFECTS_OPERATION_AND_PROPAGATION: FunctionEnums.ArgumentCollationMode
    class NamedArgumentKind(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        NAMED_ARGUMENT_KIND_UNSPECIFIED: _ClassVar[FunctionEnums.NamedArgumentKind]
        POSITIONAL_ONLY: _ClassVar[FunctionEnums.NamedArgumentKind]
        POSITIONAL_OR_NAMED: _ClassVar[FunctionEnums.NamedArgumentKind]
        NAMED_ONLY: _ClassVar[FunctionEnums.NamedArgumentKind]
    NAMED_ARGUMENT_KIND_UNSPECIFIED: FunctionEnums.NamedArgumentKind
    POSITIONAL_ONLY: FunctionEnums.NamedArgumentKind
    POSITIONAL_OR_NAMED: FunctionEnums.NamedArgumentKind
    NAMED_ONLY: FunctionEnums.NamedArgumentKind
    class ArgumentAliasKind(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        ARGUMENT_ALIAS_KIND_UNSPECIFIED: _ClassVar[FunctionEnums.ArgumentAliasKind]
        ARGUMENT_NON_ALIASED: _ClassVar[FunctionEnums.ArgumentAliasKind]
        ARGUMENT_ALIASED: _ClassVar[FunctionEnums.ArgumentAliasKind]
    ARGUMENT_ALIAS_KIND_UNSPECIFIED: FunctionEnums.ArgumentAliasKind
    ARGUMENT_NON_ALIASED: FunctionEnums.ArgumentAliasKind
    ARGUMENT_ALIASED: FunctionEnums.ArgumentAliasKind
    class DefaultNullHandling(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        DEFAULT_NULL_HANDLING_UNSPECIFIED: _ClassVar[FunctionEnums.DefaultNullHandling]
        DEFAULT_NULL_HANDLING_IGNORE_NULLS: _ClassVar[FunctionEnums.DefaultNullHandling]
        DEFAULT_NULL_HANDLING_RESPECT_NULLS: _ClassVar[FunctionEnums.DefaultNullHandling]
    DEFAULT_NULL_HANDLING_UNSPECIFIED: FunctionEnums.DefaultNullHandling
    DEFAULT_NULL_HANDLING_IGNORE_NULLS: FunctionEnums.DefaultNullHandling
    DEFAULT_NULL_HANDLING_RESPECT_NULLS: FunctionEnums.DefaultNullHandling
    def __init__(self) -> None: ...



from zetasql.wasi._pb2.zetasql.public import annotation_pb2 as _annotation_pb2
from zetasql.wasi._pb2.zetasql.public import constness_level_pb2 as _constness_level_pb2
from zetasql.wasi._pb2.zetasql.public import deprecation_warning_pb2 as _deprecation_warning_pb2
from zetasql.wasi._pb2.zetasql.public import function_pb2 as _function_pb2
from zetasql.wasi._pb2.zetasql.public import options_pb2 as _options_pb2
from zetasql.wasi._pb2.zetasql.public import parse_location_range_pb2 as _parse_location_range_pb2
from zetasql.wasi._pb2.zetasql.public import parse_resume_location_pb2 as _parse_resume_location_pb2
from zetasql.wasi._pb2.zetasql.public import simple_table_pb2 as _simple_table_pb2
from zetasql.wasi._pb2.zetasql.public import type_pb2 as _type_pb2
from zetasql.wasi._pb2.zetasql.public import value_pb2 as _value_pb2
from zetasql.wasi._pb2.zetasql.resolved_ast import resolved_ast_enums_pb2 as _resolved_ast_enums_pb2
from zetasql.wasi._pb2.zetasql.resolved_ast import serialization_pb2 as _serialization_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TVFRelationColumnProto(_message.Message):
    __slots__ = ("name", "type", "is_pseudo_column", "annotation_map", "name_parse_location_range", "type_parse_location_range")
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    IS_PSEUDO_COLUMN_FIELD_NUMBER: _ClassVar[int]
    ANNOTATION_MAP_FIELD_NUMBER: _ClassVar[int]
    NAME_PARSE_LOCATION_RANGE_FIELD_NUMBER: _ClassVar[int]
    TYPE_PARSE_LOCATION_RANGE_FIELD_NUMBER: _ClassVar[int]
    name: str
    type: _type_pb2.TypeProto
    is_pseudo_column: bool
    annotation_map: _annotation_pb2.AnnotationMapProto
    name_parse_location_range: _parse_location_range_pb2.ParseLocationRangeProto
    type_parse_location_range: _parse_location_range_pb2.ParseLocationRangeProto
    def __init__(self, name: _Optional[str] = ..., type: _Optional[_Union[_type_pb2.TypeProto, _Mapping]] = ..., is_pseudo_column: bool = ..., annotation_map: _Optional[_Union[_annotation_pb2.AnnotationMapProto, _Mapping]] = ..., name_parse_location_range: _Optional[_Union[_parse_location_range_pb2.ParseLocationRangeProto, _Mapping]] = ..., type_parse_location_range: _Optional[_Union[_parse_location_range_pb2.ParseLocationRangeProto, _Mapping]] = ...) -> None: ...

class TVFRelationProto(_message.Message):
    __slots__ = ("column", "is_value_table")
    COLUMN_FIELD_NUMBER: _ClassVar[int]
    IS_VALUE_TABLE_FIELD_NUMBER: _ClassVar[int]
    column: _containers.RepeatedCompositeFieldContainer[TVFRelationColumnProto]
    is_value_table: bool
    def __init__(self, column: _Optional[_Iterable[_Union[TVFRelationColumnProto, _Mapping]]] = ..., is_value_table: bool = ...) -> None: ...

class TVFModelProto(_message.Message):
    __slots__ = ("name", "full_name")
    NAME_FIELD_NUMBER: _ClassVar[int]
    FULL_NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    full_name: str
    def __init__(self, name: _Optional[str] = ..., full_name: _Optional[str] = ...) -> None: ...

class TVFConnectionProto(_message.Message):
    __slots__ = ("name", "full_name")
    NAME_FIELD_NUMBER: _ClassVar[int]
    FULL_NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    full_name: str
    def __init__(self, name: _Optional[str] = ..., full_name: _Optional[str] = ...) -> None: ...

class TVFDescriptorProto(_message.Message):
    __slots__ = ("column_name",)
    COLUMN_NAME_FIELD_NUMBER: _ClassVar[int]
    column_name: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, column_name: _Optional[_Iterable[str]] = ...) -> None: ...

class TVFGraphProto(_message.Message):
    __slots__ = ("name", "full_name")
    NAME_FIELD_NUMBER: _ClassVar[int]
    FULL_NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    full_name: str
    def __init__(self, name: _Optional[str] = ..., full_name: _Optional[str] = ...) -> None: ...

class FunctionArgumentTypeOptionsProto(_message.Message):
    __slots__ = ("cardinality", "must_be_constant", "must_be_non_null", "is_not_aggregate", "must_support_equality", "must_support_ordering", "min_value", "max_value", "extra_relation_input_columns_allowed", "relation_input_schema", "argument_name", "argument_name_parse_location", "argument_type_parse_location", "procedure_argument_mode", "argument_name_is_mandatory", "descriptor_resolution_table_offset", "default_value", "default_value_type", "argument_collation_mode", "uses_array_element_for_collation", "must_support_grouping", "array_element_must_support_equality", "array_element_must_support_ordering", "array_element_must_support_grouping", "named_argument_kind", "argument_alias_kind", "must_be_constant_expression", "constness_level")
    CARDINALITY_FIELD_NUMBER: _ClassVar[int]
    MUST_BE_CONSTANT_FIELD_NUMBER: _ClassVar[int]
    MUST_BE_NON_NULL_FIELD_NUMBER: _ClassVar[int]
    IS_NOT_AGGREGATE_FIELD_NUMBER: _ClassVar[int]
    MUST_SUPPORT_EQUALITY_FIELD_NUMBER: _ClassVar[int]
    MUST_SUPPORT_ORDERING_FIELD_NUMBER: _ClassVar[int]
    MIN_VALUE_FIELD_NUMBER: _ClassVar[int]
    MAX_VALUE_FIELD_NUMBER: _ClassVar[int]
    EXTRA_RELATION_INPUT_COLUMNS_ALLOWED_FIELD_NUMBER: _ClassVar[int]
    RELATION_INPUT_SCHEMA_FIELD_NUMBER: _ClassVar[int]
    ARGUMENT_NAME_FIELD_NUMBER: _ClassVar[int]
    ARGUMENT_NAME_PARSE_LOCATION_FIELD_NUMBER: _ClassVar[int]
    ARGUMENT_TYPE_PARSE_LOCATION_FIELD_NUMBER: _ClassVar[int]
    PROCEDURE_ARGUMENT_MODE_FIELD_NUMBER: _ClassVar[int]
    ARGUMENT_NAME_IS_MANDATORY_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTOR_RESOLUTION_TABLE_OFFSET_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_VALUE_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_VALUE_TYPE_FIELD_NUMBER: _ClassVar[int]
    ARGUMENT_COLLATION_MODE_FIELD_NUMBER: _ClassVar[int]
    USES_ARRAY_ELEMENT_FOR_COLLATION_FIELD_NUMBER: _ClassVar[int]
    MUST_SUPPORT_GROUPING_FIELD_NUMBER: _ClassVar[int]
    ARRAY_ELEMENT_MUST_SUPPORT_EQUALITY_FIELD_NUMBER: _ClassVar[int]
    ARRAY_ELEMENT_MUST_SUPPORT_ORDERING_FIELD_NUMBER: _ClassVar[int]
    ARRAY_ELEMENT_MUST_SUPPORT_GROUPING_FIELD_NUMBER: _ClassVar[int]
    NAMED_ARGUMENT_KIND_FIELD_NUMBER: _ClassVar[int]
    ARGUMENT_ALIAS_KIND_FIELD_NUMBER: _ClassVar[int]
    MUST_BE_CONSTANT_EXPRESSION_FIELD_NUMBER: _ClassVar[int]
    CONSTNESS_LEVEL_FIELD_NUMBER: _ClassVar[int]
    cardinality: _function_pb2.FunctionEnums.ArgumentCardinality
    must_be_constant: bool
    must_be_non_null: bool
    is_not_aggregate: bool
    must_support_equality: bool
    must_support_ordering: bool
    min_value: int
    max_value: int
    extra_relation_input_columns_allowed: bool
    relation_input_schema: TVFRelationProto
    argument_name: str
    argument_name_parse_location: _parse_location_range_pb2.ParseLocationRangeProto
    argument_type_parse_location: _parse_location_range_pb2.ParseLocationRangeProto
    procedure_argument_mode: _function_pb2.FunctionEnums.ProcedureArgumentMode
    argument_name_is_mandatory: bool
    descriptor_resolution_table_offset: int
    default_value: _value_pb2.ValueProto
    default_value_type: _type_pb2.TypeProto
    argument_collation_mode: _function_pb2.FunctionEnums.ArgumentCollationMode
    uses_array_element_for_collation: bool
    must_support_grouping: bool
    array_element_must_support_equality: bool
    array_element_must_support_ordering: bool
    array_element_must_support_grouping: bool
    named_argument_kind: _function_pb2.FunctionEnums.NamedArgumentKind
    argument_alias_kind: _function_pb2.FunctionEnums.ArgumentAliasKind
    must_be_constant_expression: bool
    constness_level: _constness_level_pb2.ConstnessLevelProto.Level
    def __init__(self, cardinality: _Optional[_Union[_function_pb2.FunctionEnums.ArgumentCardinality, str]] = ..., must_be_constant: bool = ..., must_be_non_null: bool = ..., is_not_aggregate: bool = ..., must_support_equality: bool = ..., must_support_ordering: bool = ..., min_value: _Optional[int] = ..., max_value: _Optional[int] = ..., extra_relation_input_columns_allowed: bool = ..., relation_input_schema: _Optional[_Union[TVFRelationProto, _Mapping]] = ..., argument_name: _Optional[str] = ..., argument_name_parse_location: _Optional[_Union[_parse_location_range_pb2.ParseLocationRangeProto, _Mapping]] = ..., argument_type_parse_location: _Optional[_Union[_parse_location_range_pb2.ParseLocationRangeProto, _Mapping]] = ..., procedure_argument_mode: _Optional[_Union[_function_pb2.FunctionEnums.ProcedureArgumentMode, str]] = ..., argument_name_is_mandatory: bool = ..., descriptor_resolution_table_offset: _Optional[int] = ..., default_value: _Optional[_Union[_value_pb2.ValueProto, _Mapping]] = ..., default_value_type: _Optional[_Union[_type_pb2.TypeProto, _Mapping]] = ..., argument_collation_mode: _Optional[_Union[_function_pb2.FunctionEnums.ArgumentCollationMode, str]] = ..., uses_array_element_for_collation: bool = ..., must_support_grouping: bool = ..., array_element_must_support_equality: bool = ..., array_element_must_support_ordering: bool = ..., array_element_must_support_grouping: bool = ..., named_argument_kind: _Optional[_Union[_function_pb2.FunctionEnums.NamedArgumentKind, str]] = ..., argument_alias_kind: _Optional[_Union[_function_pb2.FunctionEnums.ArgumentAliasKind, str]] = ..., must_be_constant_expression: bool = ..., constness_level: _Optional[_Union[_constness_level_pb2.ConstnessLevelProto.Level, str]] = ...) -> None: ...

class ArgumentTypeLambdaProto(_message.Message):
    __slots__ = ("argument", "body")
    ARGUMENT_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    argument: _containers.RepeatedCompositeFieldContainer[FunctionArgumentTypeProto]
    body: FunctionArgumentTypeProto
    def __init__(self, argument: _Optional[_Iterable[_Union[FunctionArgumentTypeProto, _Mapping]]] = ..., body: _Optional[_Union[FunctionArgumentTypeProto, _Mapping]] = ...) -> None: ...

class FunctionArgumentTypeProto(_message.Message):
    __slots__ = ("kind", "type", "num_occurrences", "options")
    KIND_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    NUM_OCCURRENCES_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    LAMBDA_FIELD_NUMBER: _ClassVar[int]
    kind: _function_pb2.SignatureArgumentKind
    type: _type_pb2.TypeProto
    num_occurrences: int
    options: FunctionArgumentTypeOptionsProto
    def __init__(self, kind: _Optional[_Union[_function_pb2.SignatureArgumentKind, str]] = ..., type: _Optional[_Union[_type_pb2.TypeProto, _Mapping]] = ..., num_occurrences: _Optional[int] = ..., options: _Optional[_Union[FunctionArgumentTypeOptionsProto, _Mapping]] = ..., **kwargs) -> None: ...

class FunctionSignatureRewriteOptionsProto(_message.Message):
    __slots__ = ("enabled", "rewriter", "sql", "allow_table_references", "allowed_function_groups")
    ENABLED_FIELD_NUMBER: _ClassVar[int]
    REWRITER_FIELD_NUMBER: _ClassVar[int]
    SQL_FIELD_NUMBER: _ClassVar[int]
    ALLOW_TABLE_REFERENCES_FIELD_NUMBER: _ClassVar[int]
    ALLOWED_FUNCTION_GROUPS_FIELD_NUMBER: _ClassVar[int]
    enabled: bool
    rewriter: _options_pb2.ResolvedASTRewrite
    sql: str
    allow_table_references: bool
    allowed_function_groups: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, enabled: bool = ..., rewriter: _Optional[_Union[_options_pb2.ResolvedASTRewrite, str]] = ..., sql: _Optional[str] = ..., allow_table_references: bool = ..., allowed_function_groups: _Optional[_Iterable[str]] = ...) -> None: ...

class FunctionSignatureOptionsProto(_message.Message):
    __slots__ = ("is_deprecated", "additional_deprecation_warning", "required_language_feature", "is_aliased_signature", "propagates_collation", "uses_operation_collation", "rejects_collation", "rewrite_options")
    IS_DEPRECATED_FIELD_NUMBER: _ClassVar[int]
    ADDITIONAL_DEPRECATION_WARNING_FIELD_NUMBER: _ClassVar[int]
    REQUIRED_LANGUAGE_FEATURE_FIELD_NUMBER: _ClassVar[int]
    IS_ALIASED_SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    PROPAGATES_COLLATION_FIELD_NUMBER: _ClassVar[int]
    USES_OPERATION_COLLATION_FIELD_NUMBER: _ClassVar[int]
    REJECTS_COLLATION_FIELD_NUMBER: _ClassVar[int]
    REWRITE_OPTIONS_FIELD_NUMBER: _ClassVar[int]
    is_deprecated: bool
    additional_deprecation_warning: _containers.RepeatedCompositeFieldContainer[_deprecation_warning_pb2.FreestandingDeprecationWarning]
    required_language_feature: _containers.RepeatedScalarFieldContainer[_options_pb2.LanguageFeature]
    is_aliased_signature: bool
    propagates_collation: bool
    uses_operation_collation: bool
    rejects_collation: bool
    rewrite_options: FunctionSignatureRewriteOptionsProto
    def __init__(self, is_deprecated: bool = ..., additional_deprecation_warning: _Optional[_Iterable[_Union[_deprecation_warning_pb2.FreestandingDeprecationWarning, _Mapping]]] = ..., required_language_feature: _Optional[_Iterable[_Union[_options_pb2.LanguageFeature, str]]] = ..., is_aliased_signature: bool = ..., propagates_collation: bool = ..., uses_operation_collation: bool = ..., rejects_collation: bool = ..., rewrite_options: _Optional[_Union[FunctionSignatureRewriteOptionsProto, _Mapping]] = ...) -> None: ...

class FunctionSignatureProto(_message.Message):
    __slots__ = ("argument", "return_type", "context_id", "options")
    ARGUMENT_FIELD_NUMBER: _ClassVar[int]
    RETURN_TYPE_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_ID_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    argument: _containers.RepeatedCompositeFieldContainer[FunctionArgumentTypeProto]
    return_type: FunctionArgumentTypeProto
    context_id: int
    options: FunctionSignatureOptionsProto
    def __init__(self, argument: _Optional[_Iterable[_Union[FunctionArgumentTypeProto, _Mapping]]] = ..., return_type: _Optional[_Union[FunctionArgumentTypeProto, _Mapping]] = ..., context_id: _Optional[int] = ..., options: _Optional[_Union[FunctionSignatureOptionsProto, _Mapping]] = ...) -> None: ...

class FunctionOptionsProto(_message.Message):
    __slots__ = ("supports_over_clause", "window_ordering_support", "supports_window_framing", "arguments_are_coercible", "is_deprecated", "alias_name", "sql_name", "allow_external_usage", "volatility", "supports_order_by", "required_language_feature", "supports_limit", "supports_null_handling_modifier", "supports_safe_error_mode", "supports_having_modifier", "supports_clamped_between_modifier", "uses_upper_case_sql_name", "may_suppress_side_effects", "module_name_from_import")
    SUPPORTS_OVER_CLAUSE_FIELD_NUMBER: _ClassVar[int]
    WINDOW_ORDERING_SUPPORT_FIELD_NUMBER: _ClassVar[int]
    SUPPORTS_WINDOW_FRAMING_FIELD_NUMBER: _ClassVar[int]
    ARGUMENTS_ARE_COERCIBLE_FIELD_NUMBER: _ClassVar[int]
    IS_DEPRECATED_FIELD_NUMBER: _ClassVar[int]
    ALIAS_NAME_FIELD_NUMBER: _ClassVar[int]
    SQL_NAME_FIELD_NUMBER: _ClassVar[int]
    ALLOW_EXTERNAL_USAGE_FIELD_NUMBER: _ClassVar[int]
    VOLATILITY_FIELD_NUMBER: _ClassVar[int]
    SUPPORTS_ORDER_BY_FIELD_NUMBER: _ClassVar[int]
    REQUIRED_LANGUAGE_FEATURE_FIELD_NUMBER: _ClassVar[int]
    SUPPORTS_LIMIT_FIELD_NUMBER: _ClassVar[int]
    SUPPORTS_NULL_HANDLING_MODIFIER_FIELD_NUMBER: _ClassVar[int]
    SUPPORTS_SAFE_ERROR_MODE_FIELD_NUMBER: _ClassVar[int]
    SUPPORTS_HAVING_MODIFIER_FIELD_NUMBER: _ClassVar[int]
    SUPPORTS_CLAMPED_BETWEEN_MODIFIER_FIELD_NUMBER: _ClassVar[int]
    USES_UPPER_CASE_SQL_NAME_FIELD_NUMBER: _ClassVar[int]
    MAY_SUPPRESS_SIDE_EFFECTS_FIELD_NUMBER: _ClassVar[int]
    MODULE_NAME_FROM_IMPORT_FIELD_NUMBER: _ClassVar[int]
    supports_over_clause: bool
    window_ordering_support: _function_pb2.FunctionEnums.WindowOrderSupport
    supports_window_framing: bool
    arguments_are_coercible: bool
    is_deprecated: bool
    alias_name: str
    sql_name: str
    allow_external_usage: bool
    volatility: _function_pb2.FunctionEnums.Volatility
    supports_order_by: bool
    required_language_feature: _containers.RepeatedScalarFieldContainer[_options_pb2.LanguageFeature]
    supports_limit: bool
    supports_null_handling_modifier: bool
    supports_safe_error_mode: bool
    supports_having_modifier: bool
    supports_clamped_between_modifier: bool
    uses_upper_case_sql_name: bool
    may_suppress_side_effects: bool
    module_name_from_import: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, supports_over_clause: bool = ..., window_ordering_support: _Optional[_Union[_function_pb2.FunctionEnums.WindowOrderSupport, str]] = ..., supports_window_framing: bool = ..., arguments_are_coercible: bool = ..., is_deprecated: bool = ..., alias_name: _Optional[str] = ..., sql_name: _Optional[str] = ..., allow_external_usage: bool = ..., volatility: _Optional[_Union[_function_pb2.FunctionEnums.Volatility, str]] = ..., supports_order_by: bool = ..., required_language_feature: _Optional[_Iterable[_Union[_options_pb2.LanguageFeature, str]]] = ..., supports_limit: bool = ..., supports_null_handling_modifier: bool = ..., supports_safe_error_mode: bool = ..., supports_having_modifier: bool = ..., supports_clamped_between_modifier: bool = ..., uses_upper_case_sql_name: bool = ..., may_suppress_side_effects: bool = ..., module_name_from_import: _Optional[_Iterable[str]] = ...) -> None: ...

class FunctionProto(_message.Message):
    __slots__ = ("name_path", "group", "mode", "signature", "options", "parse_resume_location", "templated_sql_function_argument_name", "sql_security", "statement_context")
    NAME_PATH_FIELD_NUMBER: _ClassVar[int]
    GROUP_FIELD_NUMBER: _ClassVar[int]
    MODE_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    PARSE_RESUME_LOCATION_FIELD_NUMBER: _ClassVar[int]
    TEMPLATED_SQL_FUNCTION_ARGUMENT_NAME_FIELD_NUMBER: _ClassVar[int]
    SQL_SECURITY_FIELD_NUMBER: _ClassVar[int]
    STATEMENT_CONTEXT_FIELD_NUMBER: _ClassVar[int]
    name_path: _containers.RepeatedScalarFieldContainer[str]
    group: str
    mode: _function_pb2.FunctionEnums.Mode
    signature: _containers.RepeatedCompositeFieldContainer[FunctionSignatureProto]
    options: FunctionOptionsProto
    parse_resume_location: _parse_resume_location_pb2.ParseResumeLocationProto
    templated_sql_function_argument_name: _containers.RepeatedScalarFieldContainer[str]
    sql_security: _resolved_ast_enums_pb2.ResolvedCreateStatementEnums.SqlSecurity
    statement_context: _options_pb2.StatementContext
    def __init__(self, name_path: _Optional[_Iterable[str]] = ..., group: _Optional[str] = ..., mode: _Optional[_Union[_function_pb2.FunctionEnums.Mode, str]] = ..., signature: _Optional[_Iterable[_Union[FunctionSignatureProto, _Mapping]]] = ..., options: _Optional[_Union[FunctionOptionsProto, _Mapping]] = ..., parse_resume_location: _Optional[_Union[_parse_resume_location_pb2.ParseResumeLocationProto, _Mapping]] = ..., templated_sql_function_argument_name: _Optional[_Iterable[str]] = ..., sql_security: _Optional[_Union[_resolved_ast_enums_pb2.ResolvedCreateStatementEnums.SqlSecurity, str]] = ..., statement_context: _Optional[_Union[_options_pb2.StatementContext, str]] = ...) -> None: ...

class ResolvedFunctionCallInfoProto(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class TableValuedFunctionOptionsProto(_message.Message):
    __slots__ = ("uses_upper_case_sql_name", "required_language_feature")
    USES_UPPER_CASE_SQL_NAME_FIELD_NUMBER: _ClassVar[int]
    REQUIRED_LANGUAGE_FEATURE_FIELD_NUMBER: _ClassVar[int]
    uses_upper_case_sql_name: bool
    required_language_feature: _containers.RepeatedScalarFieldContainer[_options_pb2.LanguageFeature]
    def __init__(self, uses_upper_case_sql_name: bool = ..., required_language_feature: _Optional[_Iterable[_Union[_options_pb2.LanguageFeature, str]]] = ...) -> None: ...

class TableValuedFunctionProto(_message.Message):
    __slots__ = ("name_path", "signature", "signatures", "options", "type", "volatility", "parse_resume_location", "argument_name", "custom_context", "anonymization_info", "statement_context", "group")
    NAME_PATH_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    SIGNATURES_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    VOLATILITY_FIELD_NUMBER: _ClassVar[int]
    PARSE_RESUME_LOCATION_FIELD_NUMBER: _ClassVar[int]
    ARGUMENT_NAME_FIELD_NUMBER: _ClassVar[int]
    CUSTOM_CONTEXT_FIELD_NUMBER: _ClassVar[int]
    ANONYMIZATION_INFO_FIELD_NUMBER: _ClassVar[int]
    STATEMENT_CONTEXT_FIELD_NUMBER: _ClassVar[int]
    GROUP_FIELD_NUMBER: _ClassVar[int]
    name_path: _containers.RepeatedScalarFieldContainer[str]
    signature: FunctionSignatureProto
    signatures: _containers.RepeatedCompositeFieldContainer[FunctionSignatureProto]
    options: TableValuedFunctionOptionsProto
    type: _function_pb2.FunctionEnums.TableValuedFunctionType
    volatility: _function_pb2.FunctionEnums.Volatility
    parse_resume_location: _parse_resume_location_pb2.ParseResumeLocationProto
    argument_name: _containers.RepeatedScalarFieldContainer[str]
    custom_context: str
    anonymization_info: _simple_table_pb2.SimpleAnonymizationInfoProto
    statement_context: _options_pb2.StatementContext
    group: str
    def __init__(self, name_path: _Optional[_Iterable[str]] = ..., signature: _Optional[_Union[FunctionSignatureProto, _Mapping]] = ..., signatures: _Optional[_Iterable[_Union[FunctionSignatureProto, _Mapping]]] = ..., options: _Optional[_Union[TableValuedFunctionOptionsProto, _Mapping]] = ..., type: _Optional[_Union[_function_pb2.FunctionEnums.TableValuedFunctionType, str]] = ..., volatility: _Optional[_Union[_function_pb2.FunctionEnums.Volatility, str]] = ..., parse_resume_location: _Optional[_Union[_parse_resume_location_pb2.ParseResumeLocationProto, _Mapping]] = ..., argument_name: _Optional[_Iterable[str]] = ..., custom_context: _Optional[str] = ..., anonymization_info: _Optional[_Union[_simple_table_pb2.SimpleAnonymizationInfoProto, _Mapping]] = ..., statement_context: _Optional[_Union[_options_pb2.StatementContext, str]] = ..., group: _Optional[str] = ...) -> None: ...

class TVFArgumentProto(_message.Message):
    __slots__ = ("scalar_argument", "relation_argument", "model_argument", "connection_argument", "descriptor_argument", "graph_argument")
    SCALAR_ARGUMENT_FIELD_NUMBER: _ClassVar[int]
    RELATION_ARGUMENT_FIELD_NUMBER: _ClassVar[int]
    MODEL_ARGUMENT_FIELD_NUMBER: _ClassVar[int]
    CONNECTION_ARGUMENT_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTOR_ARGUMENT_FIELD_NUMBER: _ClassVar[int]
    GRAPH_ARGUMENT_FIELD_NUMBER: _ClassVar[int]
    scalar_argument: _serialization_pb2.ValueWithTypeProto
    relation_argument: TVFRelationProto
    model_argument: TVFModelProto
    connection_argument: TVFConnectionProto
    descriptor_argument: TVFDescriptorProto
    graph_argument: TVFGraphProto
    def __init__(self, scalar_argument: _Optional[_Union[_serialization_pb2.ValueWithTypeProto, _Mapping]] = ..., relation_argument: _Optional[_Union[TVFRelationProto, _Mapping]] = ..., model_argument: _Optional[_Union[TVFModelProto, _Mapping]] = ..., connection_argument: _Optional[_Union[TVFConnectionProto, _Mapping]] = ..., descriptor_argument: _Optional[_Union[TVFDescriptorProto, _Mapping]] = ..., graph_argument: _Optional[_Union[TVFGraphProto, _Mapping]] = ...) -> None: ...

class TVFSignatureOptionsProto(_message.Message):
    __slots__ = ("additional_deprecation_warning",)
    ADDITIONAL_DEPRECATION_WARNING_FIELD_NUMBER: _ClassVar[int]
    additional_deprecation_warning: _containers.RepeatedCompositeFieldContainer[_deprecation_warning_pb2.FreestandingDeprecationWarning]
    def __init__(self, additional_deprecation_warning: _Optional[_Iterable[_Union[_deprecation_warning_pb2.FreestandingDeprecationWarning, _Mapping]]] = ...) -> None: ...

class TVFSignatureProto(_message.Message):
    __slots__ = ("argument", "options", "output_schema", "output_table_schema")
    ARGUMENT_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_SCHEMA_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_TABLE_SCHEMA_FIELD_NUMBER: _ClassVar[int]
    argument: _containers.RepeatedCompositeFieldContainer[TVFArgumentProto]
    options: TVFSignatureOptionsProto
    output_schema: TVFRelationProto
    output_table_schema: _serialization_pb2.TableRefProto
    def __init__(self, argument: _Optional[_Iterable[_Union[TVFArgumentProto, _Mapping]]] = ..., options: _Optional[_Union[TVFSignatureOptionsProto, _Mapping]] = ..., output_schema: _Optional[_Union[TVFRelationProto, _Mapping]] = ..., output_table_schema: _Optional[_Union[_serialization_pb2.TableRefProto, _Mapping]] = ...) -> None: ...

class ProcedureProto(_message.Message):
    __slots__ = ("name_path", "signature")
    NAME_PATH_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    name_path: _containers.RepeatedScalarFieldContainer[str]
    signature: FunctionSignatureProto
    def __init__(self, name_path: _Optional[_Iterable[str]] = ..., signature: _Optional[_Union[FunctionSignatureProto, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/public/functions/rank_type.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/public/functions/rank_type.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from zetasql.wasi._pb2.zetasql.public import type_pb2 as zetasql_dot_public_dot_type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(zetasql/public/functions/rank_type.proto\x12\x11zetasql.functions\x1a\x19zetasql/public/type.proto\"\x97\x01\n\rRankTypeEnums\"\x85\x01\n\x08RankType\x12\x1f\n\x11RANK_TYPE_UNKNOWN\x10\x00\x1a\x08\xb2\xf2\xb0\x92\x0e\x02\x08\x01\x12\x1f\n\x1b\x46RACTION_LESS_THAN_OR_EQUAL\x10\x01\x12\x0c\n\x08MIDPOINT\x10\x02\x12\x16\n\x12\x46RACTION_LESS_THAN\x10\x03\x1a\x11\xb2\xd0\xaf\xfa\r\x0b\n\tRANK_TYPEB/\n\x1c\x63om.google.zetasql.functionsB\x0fZetaSQLRankType')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.public.functions.rank_type_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.google.zetasql.functionsB\017ZetaSQLRankType'
  _globals['_RANKTYPEENUMS_RANKTYPE']._loaded_options = None
  _globals['_RANKTYPEENUMS_RANKTYPE']._serialized_options = b'\262\320\257\372\r\013\n\tRANK_TYPE'
  _globals['_RANKTYPEENUMS_RANKTYPE'].values_by_name["RANK_TYPE_UNKNOWN"]._loaded_options = None
  _globals['_RANKTYPEENUMS_RANKTYPE'].values_by_name["RANK_TYPE_UNKNOWN"]._serialized_options = b'\262\362\260\222\016\002\010\001'
  _globals['_RANKTYPEENUMS']._serialized_start=91
  _globals['_RANKTYPEENUMS']._serialized_end=242
  _globals['_RANKTYPEENUMS_RANKTYPE']._serialized_start=109
  _globals['_RANKTYPEENUMS_RANKTYPE']._serialized_end=242
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import python_message as _python_message
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ScriptException(_message.Message):
    __slots__ = ("message", "internal")
    Extensions: _python_message._ExtensionDict
    class StackTraceFrame(_message.Message):
        __slots__ = ("line", "column", "filename", "location")
        LINE_FIELD_NUMBER: _ClassVar[int]
        COLUMN_FIELD_NUMBER: _ClassVar[int]
        FILENAME_FIELD_NUMBER: _ClassVar[int]
        LOCATION_FIELD_NUMBER: _ClassVar[int]
        line: int
        column: int
        filename: str
        location: str
        def __init__(self, line: _Optional[int] = ..., column: _Optional[int] = ..., filename: _Optional[str] = ..., location: _Optional[str] = ...) -> None: ...
    class Internal(_message.Message):
        __slots__ = ("statement_text", "stack_trace")
        STATEMENT_TEXT_FIELD_NUMBER: _ClassVar[int]
        STACK_TRACE_FIELD_NUMBER: _ClassVar[int]
        statement_text: str
        stack_trace: _containers.RepeatedCompositeFieldContainer[ScriptException.StackTraceFrame]
        def __init__(self, statement_text: _Optional[str] = ..., stack_trace: _Optional[_Iterable[_Union[ScriptException.StackTraceFrame, _Mapping]]] = ...) -> None: ...
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    INTERNAL_FIELD_NUMBER: _ClassVar[int]
    message: str
    internal: ScriptException.Internal
    def __init__(self, message: _Optional[str] = ..., internal: _Optional[_Union[ScriptException.Internal, _Mapping]] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class KnownErrorMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    NONE: _ClassVar[KnownErrorMode]
    ALLOW_UNIMPLEMENTED: _ClassVar[KnownErrorMode]
    ALLOW_ERROR: _ClassVar[KnownErrorMode]
    ALLOW_ERROR_OR_WRONG_ANSWER: _ClassVar[KnownErrorMode]
    CRASHES_DO_NOT_RUN: _ClassVar[KnownErrorMode]
NONE: KnownErrorMode
ALLOW_UNIMPLEMENTED: KnownErrorMode
ALLOW_ERROR: KnownErrorMode
ALLOW_ERROR_OR_WRONG_ANSWER: KnownErrorMode
CRASHES_DO_NOT_RUN: KnownErrorMode

class KnownErrorEntry(_message.Message):
    __slots__ = ("mode", "reason", "label")
    MODE_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    LABEL_FIELD_NUMBER: _ClassVar[int]
    mode: KnownErrorMode
    reason: str
    label: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, mode: _Optional[_Union[KnownErrorMode, str]] = ..., reason: _Optional[str] = ..., label: _Optional[_Iterable[str]] = ...) -> None: ...

class KnownErrorFile(_message.Message):
    __slots__ = ("contact_email", "known_errors")
    CONTACT_EMAIL_FIELD_NUMBER: _ClassVar[int]
    KNOWN_ERRORS_FIELD_NUMBER: _ClassVar[int]
    contact_email: _containers.RepeatedScalarFieldContainer[str]
    known_errors: _containers.RepeatedCompositeFieldContainer[KnownErrorEntry]
    def __init__(self, contact_email: _Optional[_Iterable[str]] = ..., known_errors: _Optional[_Iterable[_Union[KnownErrorEntry, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/public/deprecation_warning.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/public/deprecation_warning.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from zetasql.wasi._pb2.zetasql.public import error_location_pb2 as zetasql_dot_public_dot_error__location__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(zetasql/public/deprecation_warning.proto\x12\x07zetasql\x1a#zetasql/public/error_location.proto\"\xe2\x03\n\x12\x44\x65precationWarning\x12.\n\x04kind\x18\x01 \x01(\x0e\x32 .zetasql.DeprecationWarning.Kind\"\x9b\x03\n\x04Kind\x12\x31\n$__Kind__switch_must_have_a_default__\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x17\n\x13\x44\x45PRECATED_FUNCTION\x10\x01\x12!\n\x1d\x44\x45PRECATED_FUNCTION_SIGNATURE\x10\x02\x12\x19\n\x15PROTO3_FIELD_PRESENCE\x10\x03\x12\x15\n\x11QUERY_TOO_COMPLEX\x10\x04\x12)\n%DEPRECATED_ANONYMIZATION_OPTION_KAPPA\x10\x05\x12\"\n\x1ePIVOT_OR_UNPIVOT_ON_ARRAY_SCAN\x10\x06\x12*\n&TABLE_SYNTAX_ARGUMENT_RESOLUTION_ORDER\x10\x07\x12\x0f\n\x0bPIPE_WINDOW\x10\x08\x12\x14\n\x10RESERVED_KEYWORD\x10\t\x12%\n!LEGACY_FUNCTION_OPTIONS_PLACEMENT\x10\n\x12\x1c\n\x18LATERAL_COLUMN_REFERENCE\x10\x0c\"\xb1\x01\n\x1e\x46reestandingDeprecationWarning\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x14\n\x0c\x63\x61ret_string\x18\x02 \x01(\t\x12.\n\x0e\x65rror_location\x18\x03 \x01(\x0b\x32\x16.zetasql.ErrorLocation\x12\x38\n\x13\x64\x65precation_warning\x18\x04 \x01(\x0b\x32\x1b.zetasql.DeprecationWarningB.\n\x12\x63om.google.zetasqlB\x18\x44\x65precationWarningProtos')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.public.deprecation_warning_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasqlB\030DeprecationWarningProtos'
  _globals['_DEPRECATIONWARNING']._serialized_start=91
  _globals['_DEPRECATIONWARNING']._serialized_end=573
  _globals['_DEPRECATIONWARNING_KIND']._serialized_start=162
  _globals['_DEPRECATIONWARNING_KIND']._serialized_end=573
  _globals['_FREESTANDINGDEPRECATIONWARNING']._serialized_start=576
  _globals['_FREESTANDINGDEPRECATIONWARNING']._serialized_end=753
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class ResolvedSubqueryExprEnums(_message.Message):
    __slots__ = ()
    class SubqueryType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        SCALAR: _ClassVar[ResolvedSubqueryExprEnums.SubqueryType]
        ARRAY: _ClassVar[ResolvedSubqueryExprEnums.SubqueryType]
        EXISTS: _ClassVar[ResolvedSubqueryExprEnums.SubqueryType]
        IN: _ClassVar[ResolvedSubqueryExprEnums.SubqueryType]
        LIKE_ANY: _ClassVar[ResolvedSubqueryExprEnums.SubqueryType]
        LIKE_ALL: _ClassVar[ResolvedSubqueryExprEnums.SubqueryType]
        NOT_LIKE_ANY: _ClassVar[ResolvedSubqueryExprEnums.SubqueryType]
        NOT_LIKE_ALL: _ClassVar[ResolvedSubqueryExprEnums.SubqueryType]
    SCALAR: ResolvedSubqueryExprEnums.SubqueryType
    ARRAY: ResolvedSubqueryExprEnums.SubqueryType
    EXISTS: ResolvedSubqueryExprEnums.SubqueryType
    IN: ResolvedSubqueryExprEnums.SubqueryType
    LIKE_ANY: ResolvedSubqueryExprEnums.SubqueryType
    LIKE_ALL: ResolvedSubqueryExprEnums.SubqueryType
    NOT_LIKE_ANY: ResolvedSubqueryExprEnums.SubqueryType
    NOT_LIKE_ALL: ResolvedSubqueryExprEnums.SubqueryType
    def __init__(self) -> None: ...

class ResolvedJoinScanEnums(_message.Message):
    __slots__ = ()
    class JoinType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        INNER: _ClassVar[ResolvedJoinScanEnums.JoinType]
        LEFT: _ClassVar[ResolvedJoinScanEnums.JoinType]
        RIGHT: _ClassVar[ResolvedJoinScanEnums.JoinType]
        FULL: _ClassVar[ResolvedJoinScanEnums.JoinType]
    INNER: ResolvedJoinScanEnums.JoinType
    LEFT: ResolvedJoinScanEnums.JoinType
    RIGHT: ResolvedJoinScanEnums.JoinType
    FULL: ResolvedJoinScanEnums.JoinType
    def __init__(self) -> None: ...

class ResolvedSetOperationScanEnums(_message.Message):
    __slots__ = ()
    class SetOperationType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNION_ALL: _ClassVar[ResolvedSetOperationScanEnums.SetOperationType]
        UNION_DISTINCT: _ClassVar[ResolvedSetOperationScanEnums.SetOperationType]
        INTERSECT_ALL: _ClassVar[ResolvedSetOperationScanEnums.SetOperationType]
        INTERSECT_DISTINCT: _ClassVar[ResolvedSetOperationScanEnums.SetOperationType]
        EXCEPT_ALL: _ClassVar[ResolvedSetOperationScanEnums.SetOperationType]
        EXCEPT_DISTINCT: _ClassVar[ResolvedSetOperationScanEnums.SetOperationType]
    UNION_ALL: ResolvedSetOperationScanEnums.SetOperationType
    UNION_DISTINCT: ResolvedSetOperationScanEnums.SetOperationType
    INTERSECT_ALL: ResolvedSetOperationScanEnums.SetOperationType
    INTERSECT_DISTINCT: ResolvedSetOperationScanEnums.SetOperationType
    EXCEPT_ALL: ResolvedSetOperationScanEnums.SetOperationType
    EXCEPT_DISTINCT: ResolvedSetOperationScanEnums.SetOperationType
    class SetOperationColumnMatchMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        BY_POSITION: _ClassVar[ResolvedSetOperationScanEnums.SetOperationColumnMatchMode]
        CORRESPONDING: _ClassVar[ResolvedSetOperationScanEnums.SetOperationColumnMatchMode]
        CORRESPONDING_BY: _ClassVar[ResolvedSetOperationScanEnums.SetOperationColumnMatchMode]
    BY_POSITION: ResolvedSetOperationScanEnums.SetOperationColumnMatchMode
    CORRESPONDING: ResolvedSetOperationScanEnums.SetOperationColumnMatchMode
    CORRESPONDING_BY: ResolvedSetOperationScanEnums.SetOperationColumnMatchMode
    class SetOperationColumnPropagationMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        STRICT: _ClassVar[ResolvedSetOperationScanEnums.SetOperationColumnPropagationMode]
        INNER: _ClassVar[ResolvedSetOperationScanEnums.SetOperationColumnPropagationMode]
        LEFT: _ClassVar[ResolvedSetOperationScanEnums.SetOperationColumnPropagationMode]
        FULL: _ClassVar[ResolvedSetOperationScanEnums.SetOperationColumnPropagationMode]
    STRICT: ResolvedSetOperationScanEnums.SetOperationColumnPropagationMode
    INNER: ResolvedSetOperationScanEnums.SetOperationColumnPropagationMode
    LEFT: ResolvedSetOperationScanEnums.SetOperationColumnPropagationMode
    FULL: ResolvedSetOperationScanEnums.SetOperationColumnPropagationMode
    def __init__(self) -> None: ...

class ResolvedRecursiveScanEnums(_message.Message):
    __slots__ = ()
    class RecursiveSetOperationType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNION_ALL: _ClassVar[ResolvedRecursiveScanEnums.RecursiveSetOperationType]
        UNION_DISTINCT: _ClassVar[ResolvedRecursiveScanEnums.RecursiveSetOperationType]
    UNION_ALL: ResolvedRecursiveScanEnums.RecursiveSetOperationType
    UNION_DISTINCT: ResolvedRecursiveScanEnums.RecursiveSetOperationType
    def __init__(self) -> None: ...

class ResolvedSampleScanEnums(_message.Message):
    __slots__ = ()
    class SampleUnit(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        ROWS: _ClassVar[ResolvedSampleScanEnums.SampleUnit]
        PERCENT: _ClassVar[ResolvedSampleScanEnums.SampleUnit]
    ROWS: ResolvedSampleScanEnums.SampleUnit
    PERCENT: ResolvedSampleScanEnums.SampleUnit
    def __init__(self) -> None: ...

class ResolvedOrderByItemEnums(_message.Message):
    __slots__ = ()
    class NullOrderMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        ORDER_UNSPECIFIED: _ClassVar[ResolvedOrderByItemEnums.NullOrderMode]
        NULLS_FIRST: _ClassVar[ResolvedOrderByItemEnums.NullOrderMode]
        NULLS_LAST: _ClassVar[ResolvedOrderByItemEnums.NullOrderMode]
    ORDER_UNSPECIFIED: ResolvedOrderByItemEnums.NullOrderMode
    NULLS_FIRST: ResolvedOrderByItemEnums.NullOrderMode
    NULLS_LAST: ResolvedOrderByItemEnums.NullOrderMode
    def __init__(self) -> None: ...

class ResolvedCreateStatementEnums(_message.Message):
    __slots__ = ()
    class CreateScope(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        CREATE_DEFAULT_SCOPE: _ClassVar[ResolvedCreateStatementEnums.CreateScope]
        CREATE_PRIVATE: _ClassVar[ResolvedCreateStatementEnums.CreateScope]
        CREATE_PUBLIC: _ClassVar[ResolvedCreateStatementEnums.CreateScope]
        CREATE_TEMP: _ClassVar[ResolvedCreateStatementEnums.CreateScope]
    CREATE_DEFAULT_SCOPE: ResolvedCreateStatementEnums.CreateScope
    CREATE_PRIVATE: ResolvedCreateStatementEnums.CreateScope
    CREATE_PUBLIC: ResolvedCreateStatementEnums.CreateScope
    CREATE_TEMP: ResolvedCreateStatementEnums.CreateScope
    class CreateMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        CREATE_DEFAULT: _ClassVar[ResolvedCreateStatementEnums.CreateMode]
        CREATE_OR_REPLACE: _ClassVar[ResolvedCreateStatementEnums.CreateMode]
        CREATE_IF_NOT_EXISTS: _ClassVar[ResolvedCreateStatementEnums.CreateMode]
    CREATE_DEFAULT: ResolvedCreateStatementEnums.CreateMode
    CREATE_OR_REPLACE: ResolvedCreateStatementEnums.CreateMode
    CREATE_IF_NOT_EXISTS: ResolvedCreateStatementEnums.CreateMode
    class SqlSecurity(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        SQL_SECURITY_UNSPECIFIED: _ClassVar[ResolvedCreateStatementEnums.SqlSecurity]
        SQL_SECURITY_DEFINER: _ClassVar[ResolvedCreateStatementEnums.SqlSecurity]
        SQL_SECURITY_INVOKER: _ClassVar[ResolvedCreateStatementEnums.SqlSecurity]
    SQL_SECURITY_UNSPECIFIED: ResolvedCreateStatementEnums.SqlSecurity
    SQL_SECURITY_DEFINER: ResolvedCreateStatementEnums.SqlSecurity
    SQL_SECURITY_INVOKER: ResolvedCreateStatementEnums.SqlSecurity
    class DeterminismLevel(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        DETERMINISM_UNSPECIFIED: _ClassVar[ResolvedCreateStatementEnums.DeterminismLevel]
        DETERMINISM_DETERMINISTIC: _ClassVar[ResolvedCreateStatementEnums.DeterminismLevel]
        DETERMINISM_NOT_DETERMINISTIC: _ClassVar[ResolvedCreateStatementEnums.DeterminismLevel]
        DETERMINISM_IMMUTABLE: _ClassVar[ResolvedCreateStatementEnums.DeterminismLevel]
        DETERMINISM_STABLE: _ClassVar[ResolvedCreateStatementEnums.DeterminismLevel]
        DETERMINISM_VOLATILE: _ClassVar[ResolvedCreateStatementEnums.DeterminismLevel]
    DETERMINISM_UNSPECIFIED: ResolvedCreateStatementEnums.DeterminismLevel
    DETERMINISM_DETERMINISTIC: ResolvedCreateStatementEnums.DeterminismLevel
    DETERMINISM_NOT_DETERMINISTIC: ResolvedCreateStatementEnums.DeterminismLevel
    DETERMINISM_IMMUTABLE: ResolvedCreateStatementEnums.DeterminismLevel
    DETERMINISM_STABLE: ResolvedCreateStatementEnums.DeterminismLevel
    DETERMINISM_VOLATILE: ResolvedCreateStatementEnums.DeterminismLevel
    def __init__(self) -> None: ...

class ResolvedGeneratedColumnInfoEnums(_message.Message):
    __slots__ = ()
    class StoredMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        NON_STORED: _ClassVar[ResolvedGeneratedColumnInfoEnums.StoredMode]
        STORED: _ClassVar[ResolvedGeneratedColumnInfoEnums.StoredMode]
        STORED_VOLATILE: _ClassVar[ResolvedGeneratedColumnInfoEnums.StoredMode]
    NON_STORED: ResolvedGeneratedColumnInfoEnums.StoredMode
    STORED: ResolvedGeneratedColumnInfoEnums.StoredMode
    STORED_VOLATILE: ResolvedGeneratedColumnInfoEnums.StoredMode
    class GeneratedMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        ALWAYS: _ClassVar[ResolvedGeneratedColumnInfoEnums.GeneratedMode]
        BY_DEFAULT: _ClassVar[ResolvedGeneratedColumnInfoEnums.GeneratedMode]
    ALWAYS: ResolvedGeneratedColumnInfoEnums.GeneratedMode
    BY_DEFAULT: ResolvedGeneratedColumnInfoEnums.GeneratedMode
    def __init__(self) -> None: ...

class ResolvedDropStmtEnums(_message.Message):
    __slots__ = ()
    class DropMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        DROP_MODE_UNSPECIFIED: _ClassVar[ResolvedDropStmtEnums.DropMode]
        RESTRICT: _ClassVar[ResolvedDropStmtEnums.DropMode]
        CASCADE: _ClassVar[ResolvedDropStmtEnums.DropMode]
    DROP_MODE_UNSPECIFIED: ResolvedDropStmtEnums.DropMode
    RESTRICT: ResolvedDropStmtEnums.DropMode
    CASCADE: ResolvedDropStmtEnums.DropMode
    def __init__(self) -> None: ...

class ResolvedBeginStmtEnums(_message.Message):
    __slots__ = ()
    class ReadWriteMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        MODE_UNSPECIFIED: _ClassVar[ResolvedBeginStmtEnums.ReadWriteMode]
        MODE_READ_ONLY: _ClassVar[ResolvedBeginStmtEnums.ReadWriteMode]
        MODE_READ_WRITE: _ClassVar[ResolvedBeginStmtEnums.ReadWriteMode]
    MODE_UNSPECIFIED: ResolvedBeginStmtEnums.ReadWriteMode
    MODE_READ_ONLY: ResolvedBeginStmtEnums.ReadWriteMode
    MODE_READ_WRITE: ResolvedBeginStmtEnums.ReadWriteMode
    def __init__(self) -> None: ...

class ResolvedWindowFrameEnums(_message.Message):
    __slots__ = ()
    class FrameUnit(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        ROWS: _ClassVar[ResolvedWindowFrameEnums.FrameUnit]
        RANGE: _ClassVar[ResolvedWindowFrameEnums.FrameUnit]
    ROWS: ResolvedWindowFrameEnums.FrameUnit
    RANGE: ResolvedWindowFrameEnums.FrameUnit
    def __init__(self) -> None: ...

class ResolvedWindowFrameExprEnums(_message.Message):
    __slots__ = ()
    class BoundaryType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNBOUNDED_PRECEDING: _ClassVar[ResolvedWindowFrameExprEnums.BoundaryType]
        OFFSET_PRECEDING: _ClassVar[ResolvedWindowFrameExprEnums.BoundaryType]
        CURRENT_ROW: _ClassVar[ResolvedWindowFrameExprEnums.BoundaryType]
        OFFSET_FOLLOWING: _ClassVar[ResolvedWindowFrameExprEnums.BoundaryType]
        UNBOUNDED_FOLLOWING: _ClassVar[ResolvedWindowFrameExprEnums.BoundaryType]
    UNBOUNDED_PRECEDING: ResolvedWindowFrameExprEnums.BoundaryType
    OFFSET_PRECEDING: ResolvedWindowFrameExprEnums.BoundaryType
    CURRENT_ROW: ResolvedWindowFrameExprEnums.BoundaryType
    OFFSET_FOLLOWING: ResolvedWindowFrameExprEnums.BoundaryType
    UNBOUNDED_FOLLOWING: ResolvedWindowFrameExprEnums.BoundaryType
    def __init__(self) -> None: ...

class ResolvedInsertStmtEnums(_message.Message):
    __slots__ = ()
    class InsertMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        OR_ERROR: _ClassVar[ResolvedInsertStmtEnums.InsertMode]
        OR_IGNORE: _ClassVar[ResolvedInsertStmtEnums.InsertMode]
        OR_REPLACE: _ClassVar[ResolvedInsertStmtEnums.InsertMode]
        OR_UPDATE: _ClassVar[ResolvedInsertStmtEnums.InsertMode]
    OR_ERROR: ResolvedInsertStmtEnums.InsertMode
    OR_IGNORE: ResolvedInsertStmtEnums.InsertMode
    OR_REPLACE: ResolvedInsertStmtEnums.InsertMode
    OR_UPDATE: ResolvedInsertStmtEnums.InsertMode
    def __init__(self) -> None: ...

class ResolvedMergeWhenEnums(_message.Message):
    __slots__ = ()
    class MatchType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        MATCHED: _ClassVar[ResolvedMergeWhenEnums.MatchType]
        NOT_MATCHED_BY_SOURCE: _ClassVar[ResolvedMergeWhenEnums.MatchType]
        NOT_MATCHED_BY_TARGET: _ClassVar[ResolvedMergeWhenEnums.MatchType]
    MATCHED: ResolvedMergeWhenEnums.MatchType
    NOT_MATCHED_BY_SOURCE: ResolvedMergeWhenEnums.MatchType
    NOT_MATCHED_BY_TARGET: ResolvedMergeWhenEnums.MatchType
    class ActionType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        INSERT: _ClassVar[ResolvedMergeWhenEnums.ActionType]
        UPDATE: _ClassVar[ResolvedMergeWhenEnums.ActionType]
        DELETE: _ClassVar[ResolvedMergeWhenEnums.ActionType]
    INSERT: ResolvedMergeWhenEnums.ActionType
    UPDATE: ResolvedMergeWhenEnums.ActionType
    DELETE: ResolvedMergeWhenEnums.ActionType
    def __init__(self) -> None: ...

class ResolvedOnConflictClauseEnums(_message.Message):
    __slots__ = ()
    class ConflictAction(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        NOTHING: _ClassVar[ResolvedOnConflictClauseEnums.ConflictAction]
        UPDATE: _ClassVar[ResolvedOnConflictClauseEnums.ConflictAction]
    NOTHING: ResolvedOnConflictClauseEnums.ConflictAction
    UPDATE: ResolvedOnConflictClauseEnums.ConflictAction
    def __init__(self) -> None: ...

class ResolvedArgumentDefEnums(_message.Message):
    __slots__ = ()
    class ArgumentKind(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        SCALAR: _ClassVar[ResolvedArgumentDefEnums.ArgumentKind]
        AGGREGATE: _ClassVar[ResolvedArgumentDefEnums.ArgumentKind]
        NOT_AGGREGATE: _ClassVar[ResolvedArgumentDefEnums.ArgumentKind]
    SCALAR: ResolvedArgumentDefEnums.ArgumentKind
    AGGREGATE: ResolvedArgumentDefEnums.ArgumentKind
    NOT_AGGREGATE: ResolvedArgumentDefEnums.ArgumentKind
    def __init__(self) -> None: ...

class ResolvedFunctionCallBaseEnums(_message.Message):
    __slots__ = ()
    class ErrorMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        DEFAULT_ERROR_MODE: _ClassVar[ResolvedFunctionCallBaseEnums.ErrorMode]
        SAFE_ERROR_MODE: _ClassVar[ResolvedFunctionCallBaseEnums.ErrorMode]
    DEFAULT_ERROR_MODE: ResolvedFunctionCallBaseEnums.ErrorMode
    SAFE_ERROR_MODE: ResolvedFunctionCallBaseEnums.ErrorMode
    def __init__(self) -> None: ...

class ResolvedNonScalarFunctionCallBaseEnums(_message.Message):
    __slots__ = ()
    class NullHandlingModifier(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        DEFAULT_NULL_HANDLING: _ClassVar[ResolvedNonScalarFunctionCallBaseEnums.NullHandlingModifier]
        IGNORE_NULLS: _ClassVar[ResolvedNonScalarFunctionCallBaseEnums.NullHandlingModifier]
        RESPECT_NULLS: _ClassVar[ResolvedNonScalarFunctionCallBaseEnums.NullHandlingModifier]
    DEFAULT_NULL_HANDLING: ResolvedNonScalarFunctionCallBaseEnums.NullHandlingModifier
    IGNORE_NULLS: ResolvedNonScalarFunctionCallBaseEnums.NullHandlingModifier
    RESPECT_NULLS: ResolvedNonScalarFunctionCallBaseEnums.NullHandlingModifier
    def __init__(self) -> None: ...

class ResolvedAggregateHavingModifierEnums(_message.Message):
    __slots__ = ()
    class HavingModifierKind(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        INVALID: _ClassVar[ResolvedAggregateHavingModifierEnums.HavingModifierKind]
        MAX: _ClassVar[ResolvedAggregateHavingModifierEnums.HavingModifierKind]
        MIN: _ClassVar[ResolvedAggregateHavingModifierEnums.HavingModifierKind]
    INVALID: ResolvedAggregateHavingModifierEnums.HavingModifierKind
    MAX: ResolvedAggregateHavingModifierEnums.HavingModifierKind
    MIN: ResolvedAggregateHavingModifierEnums.HavingModifierKind
    def __init__(self) -> None: ...

class ResolvedStatementEnums(_message.Message):
    __slots__ = ()
    class ObjectAccess(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        NONE: _ClassVar[ResolvedStatementEnums.ObjectAccess]
        READ: _ClassVar[ResolvedStatementEnums.ObjectAccess]
        WRITE: _ClassVar[ResolvedStatementEnums.ObjectAccess]
        READ_WRITE: _ClassVar[ResolvedStatementEnums.ObjectAccess]
    NONE: ResolvedStatementEnums.ObjectAccess
    READ: ResolvedStatementEnums.ObjectAccess
    WRITE: ResolvedStatementEnums.ObjectAccess
    READ_WRITE: ResolvedStatementEnums.ObjectAccess
    def __init__(self) -> None: ...

class ResolvedImportStmtEnums(_message.Message):
    __slots__ = ()
    class ImportKind(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        MODULE: _ClassVar[ResolvedImportStmtEnums.ImportKind]
        PROTO: _ClassVar[ResolvedImportStmtEnums.ImportKind]
        __ImportKind__switch_must_have_a_default__: _ClassVar[ResolvedImportStmtEnums.ImportKind]
    MODULE: ResolvedImportStmtEnums.ImportKind
    PROTO: ResolvedImportStmtEnums.ImportKind
    __ImportKind__switch_must_have_a_default__: ResolvedImportStmtEnums.ImportKind
    def __init__(self) -> None: ...

class ResolvedForeignKeyEnums(_message.Message):
    __slots__ = ()
    class MatchMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        SIMPLE: _ClassVar[ResolvedForeignKeyEnums.MatchMode]
        FULL: _ClassVar[ResolvedForeignKeyEnums.MatchMode]
        NOT_DISTINCT: _ClassVar[ResolvedForeignKeyEnums.MatchMode]
    SIMPLE: ResolvedForeignKeyEnums.MatchMode
    FULL: ResolvedForeignKeyEnums.MatchMode
    NOT_DISTINCT: ResolvedForeignKeyEnums.MatchMode
    class ActionOperation(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        NO_ACTION: _ClassVar[ResolvedForeignKeyEnums.ActionOperation]
        RESTRICT: _ClassVar[ResolvedForeignKeyEnums.ActionOperation]
        CASCADE: _ClassVar[ResolvedForeignKeyEnums.ActionOperation]
        SET_NULL: _ClassVar[ResolvedForeignKeyEnums.ActionOperation]
    NO_ACTION: ResolvedForeignKeyEnums.ActionOperation
    RESTRICT: ResolvedForeignKeyEnums.ActionOperation
    CASCADE: ResolvedForeignKeyEnums.ActionOperation
    SET_NULL: ResolvedForeignKeyEnums.ActionOperation
    def __init__(self) -> None: ...

class ResolvedAuxLoadDataStmtEnums(_message.Message):
    __slots__ = ()
    class InsertionMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        NONE: _ClassVar[ResolvedAuxLoadDataStmtEnums.InsertionMode]
        APPEND: _ClassVar[ResolvedAuxLoadDataStmtEnums.InsertionMode]
        OVERWRITE: _ClassVar[ResolvedAuxLoadDataStmtEnums.InsertionMode]
    NONE: ResolvedAuxLoadDataStmtEnums.InsertionMode
    APPEND: ResolvedAuxLoadDataStmtEnums.InsertionMode
    OVERWRITE: ResolvedAuxLoadDataStmtEnums.InsertionMode
    def __init__(self) -> None: ...

class ResolvedMatchRecognizeScanEnums(_message.Message):
    __slots__ = ()
    class AfterMatchSkipMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        AFTER_MATCH_SKIP_MODE_UNSPECIFIED: _ClassVar[ResolvedMatchRecognizeScanEnums.AfterMatchSkipMode]
        END_OF_MATCH: _ClassVar[ResolvedMatchRecognizeScanEnums.AfterMatchSkipMode]
        NEXT_ROW: _ClassVar[ResolvedMatchRecognizeScanEnums.AfterMatchSkipMode]
    AFTER_MATCH_SKIP_MODE_UNSPECIFIED: ResolvedMatchRecognizeScanEnums.AfterMatchSkipMode
    END_OF_MATCH: ResolvedMatchRecognizeScanEnums.AfterMatchSkipMode
    NEXT_ROW: ResolvedMatchRecognizeScanEnums.AfterMatchSkipMode
    def __init__(self) -> None: ...

class ResolvedMatchRecognizePatternAnchorEnums(_message.Message):
    __slots__ = ()
    class Mode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        MODE_UNSPECIFIED: _ClassVar[ResolvedMatchRecognizePatternAnchorEnums.Mode]
        START: _ClassVar[ResolvedMatchRecognizePatternAnchorEnums.Mode]
        END: _ClassVar[ResolvedMatchRecognizePatternAnchorEnums.Mode]
    MODE_UNSPECIFIED: ResolvedMatchRecognizePatternAnchorEnums.Mode
    START: ResolvedMatchRecognizePatternAnchorEnums.Mode
    END: ResolvedMatchRecognizePatternAnchorEnums.Mode
    def __init__(self) -> None: ...

class ResolvedMatchRecognizePatternOperationEnums(_message.Message):
    __slots__ = ()
    class MatchRecognizePatternOperationType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        OPERATION_TYPE_UNSPECIFIED: _ClassVar[ResolvedMatchRecognizePatternOperationEnums.MatchRecognizePatternOperationType]
        CONCAT: _ClassVar[ResolvedMatchRecognizePatternOperationEnums.MatchRecognizePatternOperationType]
        ALTERNATE: _ClassVar[ResolvedMatchRecognizePatternOperationEnums.MatchRecognizePatternOperationType]
    OPERATION_TYPE_UNSPECIFIED: ResolvedMatchRecognizePatternOperationEnums.MatchRecognizePatternOperationType
    CONCAT: ResolvedMatchRecognizePatternOperationEnums.MatchRecognizePatternOperationType
    ALTERNATE: ResolvedMatchRecognizePatternOperationEnums.MatchRecognizePatternOperationType
    def __init__(self) -> None: ...

class ResolvedGraphLabelNaryExprEnums(_message.Message):
    __slots__ = ()
    class GraphLogicalOpType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        OPERATION_TYPE_UNSPECIFIED: _ClassVar[ResolvedGraphLabelNaryExprEnums.GraphLogicalOpType]
        NOT: _ClassVar[ResolvedGraphLabelNaryExprEnums.GraphLogicalOpType]
        AND: _ClassVar[ResolvedGraphLabelNaryExprEnums.GraphLogicalOpType]
        OR: _ClassVar[ResolvedGraphLabelNaryExprEnums.GraphLogicalOpType]
    OPERATION_TYPE_UNSPECIFIED: ResolvedGraphLabelNaryExprEnums.GraphLogicalOpType
    NOT: ResolvedGraphLabelNaryExprEnums.GraphLogicalOpType
    AND: ResolvedGraphLabelNaryExprEnums.GraphLogicalOpType
    OR: ResolvedGraphLabelNaryExprEnums.GraphLogicalOpType
    def __init__(self) -> None: ...

class ResolvedGraphEdgeScanEnums(_message.Message):
    __slots__ = ()
    class EdgeOrientation(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        ANY: _ClassVar[ResolvedGraphEdgeScanEnums.EdgeOrientation]
        LEFT: _ClassVar[ResolvedGraphEdgeScanEnums.EdgeOrientation]
        RIGHT: _ClassVar[ResolvedGraphEdgeScanEnums.EdgeOrientation]
    ANY: ResolvedGraphEdgeScanEnums.EdgeOrientation
    LEFT: ResolvedGraphEdgeScanEnums.EdgeOrientation
    RIGHT: ResolvedGraphEdgeScanEnums.EdgeOrientation
    def __init__(self) -> None: ...

class ResolvedGraphPathModeEnums(_message.Message):
    __slots__ = ()
    class PathMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        PATH_MODE_UNSPECIFIED: _ClassVar[ResolvedGraphPathModeEnums.PathMode]
        WALK: _ClassVar[ResolvedGraphPathModeEnums.PathMode]
        TRAIL: _ClassVar[ResolvedGraphPathModeEnums.PathMode]
        SIMPLE: _ClassVar[ResolvedGraphPathModeEnums.PathMode]
        ACYCLIC: _ClassVar[ResolvedGraphPathModeEnums.PathMode]
    PATH_MODE_UNSPECIFIED: ResolvedGraphPathModeEnums.PathMode
    WALK: ResolvedGraphPathModeEnums.PathMode
    TRAIL: ResolvedGraphPathModeEnums.PathMode
    SIMPLE: ResolvedGraphPathModeEnums.PathMode
    ACYCLIC: ResolvedGraphPathModeEnums.PathMode
    def __init__(self) -> None: ...

class ResolvedGraphPathSearchPrefixEnums(_message.Message):
    __slots__ = ()
    class PathSearchPrefixType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        PATH_SEARCH_PREFIX_TYPE_UNSPECIFIED: _ClassVar[ResolvedGraphPathSearchPrefixEnums.PathSearchPrefixType]
        ANY: _ClassVar[ResolvedGraphPathSearchPrefixEnums.PathSearchPrefixType]
        SHORTEST: _ClassVar[ResolvedGraphPathSearchPrefixEnums.PathSearchPrefixType]
        CHEAPEST: _ClassVar[ResolvedGraphPathSearchPrefixEnums.PathSearchPrefixType]
    PATH_SEARCH_PREFIX_TYPE_UNSPECIFIED: ResolvedGraphPathSearchPrefixEnums.PathSearchPrefixType
    ANY: ResolvedGraphPathSearchPrefixEnums.PathSearchPrefixType
    SHORTEST: ResolvedGraphPathSearchPrefixEnums.PathSearchPrefixType
    CHEAPEST: ResolvedGraphPathSearchPrefixEnums.PathSearchPrefixType
    def __init__(self) -> None: ...

class ResolvedDropIndexStmtEnums(_message.Message):
    __slots__ = ()
    class IndexType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        INDEX_DEFAULT: _ClassVar[ResolvedDropIndexStmtEnums.IndexType]
        INDEX_SEARCH: _ClassVar[ResolvedDropIndexStmtEnums.IndexType]
        INDEX_VECTOR: _ClassVar[ResolvedDropIndexStmtEnums.IndexType]
    INDEX_DEFAULT: ResolvedDropIndexStmtEnums.IndexType
    INDEX_SEARCH: ResolvedDropIndexStmtEnums.IndexType
    INDEX_VECTOR: ResolvedDropIndexStmtEnums.IndexType
    def __init__(self) -> None: ...

class ResolvedOptionEnums(_message.Message):
    __slots__ = ()
    class AssignmentOp(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        DEFAULT_ASSIGN: _ClassVar[ResolvedOptionEnums.AssignmentOp]
        ADD_ASSIGN: _ClassVar[ResolvedOptionEnums.AssignmentOp]
        SUB_ASSIGN: _ClassVar[ResolvedOptionEnums.AssignmentOp]
    DEFAULT_ASSIGN: ResolvedOptionEnums.AssignmentOp
    ADD_ASSIGN: ResolvedOptionEnums.AssignmentOp
    SUB_ASSIGN: ResolvedOptionEnums.AssignmentOp
    def __init__(self) -> None: ...

class ResolvedLockModeEnums(_message.Message):
    __slots__ = ()
    class LockStrengthType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UPDATE: _ClassVar[ResolvedLockModeEnums.LockStrengthType]
    UPDATE: ResolvedLockModeEnums.LockStrengthType
    def __init__(self) -> None: ...

class ResolvedAlterIndexStmtEnums(_message.Message):
    __slots__ = ()
    class AlterIndexType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        INDEX_DEFAULT: _ClassVar[ResolvedAlterIndexStmtEnums.AlterIndexType]
        INDEX_SEARCH: _ClassVar[ResolvedAlterIndexStmtEnums.AlterIndexType]
        INDEX_VECTOR: _ClassVar[ResolvedAlterIndexStmtEnums.AlterIndexType]
    INDEX_DEFAULT: ResolvedAlterIndexStmtEnums.AlterIndexType
    INDEX_SEARCH: ResolvedAlterIndexStmtEnums.AlterIndexType
    INDEX_VECTOR: ResolvedAlterIndexStmtEnums.AlterIndexType
    def __init__(self) -> None: ...

class ResolvedUpdateFieldItemEnums(_message.Message):
    __slots__ = ()
    class Operation(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UPDATE_SINGLE: _ClassVar[ResolvedUpdateFieldItemEnums.Operation]
        UPDATE_MANY: _ClassVar[ResolvedUpdateFieldItemEnums.Operation]
        UPDATE_SINGLE_NO_CREATION: _ClassVar[ResolvedUpdateFieldItemEnums.Operation]
    UPDATE_SINGLE: ResolvedUpdateFieldItemEnums.Operation
    UPDATE_MANY: ResolvedUpdateFieldItemEnums.Operation
    UPDATE_SINGLE_NO_CREATION: ResolvedUpdateFieldItemEnums.Operation
    def __init__(self) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class FormatterOptionsProto(_message.Message):
    __slots__ = ("new_line_type", "line_length_limit", "indentation_spaces", "allow_invalid_tokens", "capitalize_keywords", "preserve_line_breaks", "expand_format_ranges", "enforce_single_quotes", "capitalize_functions", "format_structured_strings", "format_comments")
    NEW_LINE_TYPE_FIELD_NUMBER: _ClassVar[int]
    LINE_LENGTH_LIMIT_FIELD_NUMBER: _ClassVar[int]
    INDENTATION_SPACES_FIELD_NUMBER: _ClassVar[int]
    ALLOW_INVALID_TOKENS_FIELD_NUMBER: _ClassVar[int]
    CAPITALIZE_KEYWORDS_FIELD_NUMBER: _ClassVar[int]
    PRESERVE_LINE_BREAKS_FIELD_NUMBER: _ClassVar[int]
    EXPAND_FORMAT_RANGES_FIELD_NUMBER: _ClassVar[int]
    ENFORCE_SINGLE_QUOTES_FIELD_NUMBER: _ClassVar[int]
    CAPITALIZE_FUNCTIONS_FIELD_NUMBER: _ClassVar[int]
    FORMAT_STRUCTURED_STRINGS_FIELD_NUMBER: _ClassVar[int]
    FORMAT_COMMENTS_FIELD_NUMBER: _ClassVar[int]
    new_line_type: str
    line_length_limit: int
    indentation_spaces: int
    allow_invalid_tokens: bool
    capitalize_keywords: bool
    preserve_line_breaks: bool
    expand_format_ranges: bool
    enforce_single_quotes: bool
    capitalize_functions: bool
    format_structured_strings: bool
    format_comments: bool
    def __init__(self, new_line_type: _Optional[str] = ..., line_length_limit: _Optional[int] = ..., indentation_spaces: _Optional[int] = ..., allow_invalid_tokens: bool = ..., capitalize_keywords: bool = ..., preserve_line_breaks: bool = ..., expand_format_ranges: bool = ..., enforce_single_quotes: bool = ..., capitalize_functions: bool = ..., format_structured_strings: bool = ..., format_comments: bool = ...) -> None: ...

class FormatterRangeProto(_message.Message):
    __slots__ = ("start", "end")
    START_FIELD_NUMBER: _ClassVar[int]
    END_FIELD_NUMBER: _ClassVar[int]
    start: int
    end: int
    def __init__(self, start: _Optional[int] = ..., end: _Optional[int] = ...) -> None: ...



from zetasql.wasi._pb2.zetasql.public import type_pb2 as _type_pb2
from zetasql.wasi._pb2.zetasql.public import type_parameters_pb2 as _type_parameters_pb2
from zetasql.wasi._pb2.zetasql.public import value_pb2 as _value_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Variable(_message.Message):
    __slots__ = ("name", "type", "value", "type_params")
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    TYPE_PARAMS_FIELD_NUMBER: _ClassVar[int]
    name: str
    type: _type_pb2.TypeProto
    value: _value_pb2.ValueProto
    type_params: _type_parameters_pb2.TypeParametersProto
    def __init__(self, name: _Optional[str] = ..., type: _Optional[_Union[_type_pb2.TypeProto, _Mapping]] = ..., value: _Optional[_Union[_value_pb2.ValueProto, _Mapping]] = ..., type_params: _Optional[_Union[_type_parameters_pb2.TypeParametersProto, _Mapping]] = ...) -> None: ...



from typing import TypeVar

from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf import message as _message

from zetasql import types
from zetasql.core.func_utils import parameters
from zetasql.core.wasm_client import WasmClient
from zetasql.types import parse_proto
from zetasql.wasi import get_wasm_path
from zetasql.wasi._pb2.zetasql.local_service import local_service_pb2
from zetasql.wasi._pb2.zetasql.proto import options_pb2
from zetasql.wasi._pb2.zetasql.public import simple_table_pb2

Message = TypeVar("Message", bound=_message.Message)


class ZetaSqlLocalService:
    """Client for ZetaSQL Local Service via WASM.

    Uses ProtoModel objects for all API interactions. ProtoModel objects
    provide type-safe dataclass interfaces with automatic protobuf conversion.
    """

    def __init__(self):
        """Initialize the ZetaSQL Local Service client."""
        self.wasm_client = WasmClient(wasm_path=get_wasm_path())

    @parameters(types.PrepareRequest)
    def prepare(self, *args, **kwargs):
        return parse_proto(
            self.wasm_client.call_grpc_func(
                "ZetaSqlLocalService_Prepare",
                types.PrepareRequest(*args, **kwargs).to_proto(),
                local_service_pb2.PrepareResponse,
            ),
        ).as_type(types.PrepareResponse)

    @parameters(types.EvaluateRequest)
    def evaluate(self, *args, **kwargs):
        return parse_proto(
            self.wasm_client.call_grpc_func(
                "ZetaSqlLocalService_Evaluate",
                types.EvaluateRequest(*args, **kwargs).to_proto(),
                local_service_pb2.EvaluateResponse,
            ),
        ).as_type(types.EvaluateResponse)

    @parameters(types.UnprepareRequest)
    def unprepare(self, *args, **kwargs):
        parse_proto(
            self.wasm_client.call_grpc_func(
                "ZetaSqlLocalService_Unprepare",
                types.UnprepareRequest(*args, **kwargs).to_proto(),
                _empty_pb2.Empty,
            ),
        )

    @parameters(types.PrepareQueryRequest)
    def prepare_query(self, *args, **kwargs):
        return parse_proto(
            self.wasm_client.call_grpc_func(
                "ZetaSqlLocalService_PrepareQuery",
                types.PrepareQueryRequest(*args, **kwargs).to_proto(),
                local_service_pb2.PrepareQueryResponse,
            ),
        ).as_type(types.PrepareQueryResponse)

    @parameters(types.EvaluateQueryRequest)
    def evaluate_query(self, *args, **kwargs):
        return parse_proto(
            self.wasm_client.call_grpc_func(
                "ZetaSqlLocalService_EvaluateQuery",
                types.EvaluateQueryRequest(*args, **kwargs).to_proto(),
                local_service_pb2.EvaluateQueryResponse,
            ),
        ).as_type(types.EvaluateQueryResponse)

    @parameters(types.UnprepareQueryRequest)
    def unprepare_query(self, *args, **kwargs):
        parse_proto(
            self.wasm_client.call_grpc_func(
                "ZetaSqlLocalService_UnprepareQuery",
                types.UnprepareQueryRequest(*args, **kwargs).to_proto(),
                _empty_pb2.Empty,
            ),
        )

    @parameters(types.PrepareModifyRequest)
    def prepare_modify(self, *args, **kwargs):
        return parse_proto(
            self.wasm_client.call_grpc_func(
                "ZetaSqlLocalService_PrepareModify",
                types.PrepareModifyRequest(*args, **kwargs).to_proto(),
                local_service_pb2.PrepareModifyResponse,
            ),
        ).as_type(types.PrepareModifyResponse)

    @parameters(types.EvaluateModifyRequest)
    def evaluate_modify(self, *args, **kwargs):
        return parse_proto(
            self.wasm_client.call_grpc_func(
                "ZetaSqlLocalService_EvaluateModify",
                types.EvaluateModifyRequest(*args, **kwargs).to_proto(),
                local_service_pb2.EvaluateModifyResponse,
            ),
        ).as_type(types.EvaluateModifyResponse)

    @parameters(types.UnprepareModifyRequest)
    def unprepare_modify(self, *args, **kwargs):
        parse_proto(
            self.wasm_client.call_grpc_func(
                "ZetaSqlLocalService_UnprepareModify",
                types.UnprepareModifyRequest(*args, **kwargs).to_proto(),
                _empty_pb2.Empty,
            ),
        )

    @parameters(types.AnalyzeRequest)
    def analyze(self, *args, **kwargs):
        return parse_proto(
            self.wasm_client.call_grpc_func(
                "ZetaSqlLocalService_Analyze",
                types.AnalyzeRequest(*args, **kwargs).to_proto(),
                local_service_pb2.AnalyzeResponse,
            ),
        ).as_type(types.AnalyzeResponse)

    @parameters(types.BuildSqlRequest)
    def build_sql(self, *args, **kwargs):
        return parse_proto(
            self.wasm_client.call_grpc_func(
                "ZetaSqlLocalService_BuildSql",
                types.BuildSqlRequest(*args, **kwargs).to_proto(),
                local_service_pb2.BuildSqlResponse,
            ),
        ).as_type(types.BuildSqlResponse)

    @parameters(types.ParseRequest)
    def parse(self, *args, **kwargs):
        return parse_proto(
            self.wasm_client.call_grpc_func(
                "ZetaSqlLocalService_Parse",
                types.ParseRequest(*args, **kwargs).to_proto(),
                local_service_pb2.ParseResponse,
            ),
        ).as_type(types.ParseResponse)

    @parameters(types.ExtractTableNamesFromStatementRequest)
    def extract_table_names_from_statement(self, *args, **kwargs):
        return parse_proto(
            self.wasm_client.call_grpc_func(
                "ZetaSqlLocalService_ExtractTableNamesFromStatement",
                types.ExtractTableNamesFromStatementRequest(*args, **kwargs).to_proto(),
                local_service_pb2.ExtractTableNamesFromStatementResponse,
            ),
        ).as_type(types.ExtractTableNamesFromStatementResponse)

    @parameters(types.ExtractTableNamesFromNextStatementRequest)
    def extract_table_names_from_next_statement(self, *args, **kwargs):
        return parse_proto(
            self.wasm_client.call_grpc_func(
                "ZetaSqlLocalService_ExtractTableNamesFromNextStatement",
                types.ExtractTableNamesFromNextStatementRequest(*args, **kwargs).to_proto(),
                local_service_pb2.ExtractTableNamesFromNextStatementResponse,
            ),
        ).as_type(types.ExtractTableNamesFromNextStatementResponse)

    @parameters(types.TableFromProtoRequest)
    def get_table_from_proto(self, *args, **kwargs):
        return parse_proto(
            self.wasm_client.call_grpc_func(
                "ZetaSqlLocalService_GetTableFromProto",
                types.TableFromProtoRequest(*args, **kwargs).to_proto(),
                simple_table_pb2.SimpleTableProto,
            ),
        ).as_type(types.SimpleTable)

    @parameters(types.FormatSqlRequest)
    def format_sql(self, *args, **kwargs):
        return parse_proto(
            self.wasm_client.call_grpc_func(
                "ZetaSqlLocalService_FormatSql",
                types.FormatSqlRequest(*args, **kwargs).to_proto(),
                local_service_pb2.FormatSqlResponse,
            ),
        ).as_type(types.FormatSqlResponse)

    @parameters(types.FormatSqlRequest)
    def lenient_format_sql(self, *args, **kwargs):
        return parse_proto(
            self.wasm_client.call_grpc_func(
                "ZetaSqlLocalService_LenientFormatSql",
                types.FormatSqlRequest(*args, **kwargs).to_proto(),
                local_service_pb2.FormatSqlResponse,
            ),
        ).as_type(types.FormatSqlResponse)

    @parameters(types.RegisterCatalogRequest)
    def register_catalog(self, *args, **kwargs):
        return parse_proto(
            self.wasm_client.call_grpc_func(
                "ZetaSqlLocalService_RegisterCatalog",
                types.RegisterCatalogRequest(*args, **kwargs).to_proto(),
                local_service_pb2.RegisterResponse,
            ),
        ).as_type(types.RegisterResponse)

    @parameters(types.UnregisterRequest)
    def unregister_catalog(self, *args, **kwargs):
        parse_proto(
            self.wasm_client.call_grpc_func(
                "ZetaSqlLocalService_UnregisterCatalog",
                types.UnregisterRequest(*args, **kwargs).to_proto(),
                _empty_pb2.Empty,
            ),
        )

    @parameters(types.ZetaSQLBuiltinFunctionOptions)
    def get_builtin_functions(self, *args, **kwargs):
        return parse_proto(
            self.wasm_client.call_grpc_func(
                "ZetaSqlLocalService_GetBuiltinFunctions",
                types.ZetaSQLBuiltinFunctionOptions(*args, **kwargs).to_proto(),
                local_service_pb2.GetBuiltinFunctionsResponse,
            ),
        ).as_type(types.GetBuiltinFunctionsResponse)

    @parameters(types.LanguageOptionsRequest)
    def get_language_options(self, *args, **kwargs):
        return parse_proto(
            self.wasm_client.call_grpc_func(
                "ZetaSqlLocalService_GetLanguageOptions",
                types.LanguageOptionsRequest(*args, **kwargs).to_proto(),
                options_pb2.LanguageOptionsProto,
            ),
        ).as_type(types.LanguageOptions)

    @parameters(types.AnalyzerOptionsRequest)
    def get_analyzer_options(self, *args, **kwargs):
        return parse_proto(
            self.wasm_client.call_grpc_func(
                "ZetaSqlLocalService_GetAnalyzerOptions",
                types.AnalyzerOptionsRequest(*args, **kwargs).to_proto(),
                options_pb2.AnalyzerOptionsProto,
            ),
        ).as_type(types.AnalyzerOptions)

    @classmethod
    def get_instance(cls):
        if not hasattr(cls, "_instance"):
            cls._instance = cls()
        return cls._instance



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/proto/module_options.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/proto/module_options.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"zetasql/proto/module_options.proto\x12\x07zetasql\"\xb1\x02\n\x10PerModuleOptions\x12\x1a\n\x12udf_server_address\x18\x01 \x01(\t\x12\x15\n\rudf_namespace\x18\x04 \x01(\t\x12i\n\x16udf_server_import_mode\x18\x02 \x01(\x0e\x32-.zetasql.PerModuleOptions.UdfServerImportMode:\x1aSERVER_ADDRESS_FROM_MODULE\x12\x1a\n\x12udf_scaling_factor\x18\x03 \x01(\x01\"c\n\x13UdfServerImportMode\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x1e\n\x1aSERVER_ADDRESS_FROM_MODULE\x10\x01\x12\x13\n\x0f\x43\x41LLER_PROVIDED\x10\x02\x12\n\n\x06MANUAL\x10\x03\"\xe0\x01\n\rModuleOptions\x12\x31\n\x0eglobal_options\x18\x01 \x01(\x0b\x32\x19.zetasql.PerModuleOptions\x12H\n\x12per_module_options\x18\x02 \x03(\x0b\x32,.zetasql.ModuleOptions.PerModuleOptionsEntry\x1aR\n\x15PerModuleOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x19.zetasql.PerModuleOptions:\x02\x38\x01\x42\x02P\x01')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.proto.module_options_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'P\001'
  _globals['_MODULEOPTIONS_PERMODULEOPTIONSENTRY']._loaded_options = None
  _globals['_MODULEOPTIONS_PERMODULEOPTIONSENTRY']._serialized_options = b'8\001'
  _globals['_PERMODULEOPTIONS']._serialized_start=48
  _globals['_PERMODULEOPTIONS']._serialized_end=353
  _globals['_PERMODULEOPTIONS_UDFSERVERIMPORTMODE']._serialized_start=254
  _globals['_PERMODULEOPTIONS_UDFSERVERIMPORTMODE']._serialized_end=353
  _globals['_MODULEOPTIONS']._serialized_start=356
  _globals['_MODULEOPTIONS']._serialized_end=580
  _globals['_MODULEOPTIONS_PERMODULEOPTIONSENTRY']._serialized_start=498
  _globals['_MODULEOPTIONS_PERMODULEOPTIONSENTRY']._serialized_end=580
# @@protoc_insertion_point(module_scope)
